@@ -6,8 +6,11 @@ ICONPATH = 'icons/'
 aux0 = gFld("Variables", "varsRightFrame.html")
 foldersTree = aux0
 aux1 = insFld(aux0, gFld("A", "javascript:parent.op()"))
+insDoc(aux1, gLnk("R", "ABCapHeight", "vars/Time-Dependent.html#ABCapHeight"))
 insDoc(aux1, gLnk("R", "ABHeight", "vars/Time-Dependent.html#ABHeight"))
+insDoc(aux1, gLnk("R", "ABShape", "vars/Time-Dependent.html#ABShape"))
 insDoc(aux1, gLnk("R", "AbsorbingBoundaries", "vars/Time-Dependent.html#AbsorbingBoundaries"))
+insDoc(aux1, gLnk("R", "ABType", "vars/Time-Dependent.html#ABType"))
 insDoc(aux1, gLnk("R", "ABWidth", "vars/Time-Dependent.html#ABWidth"))
 insDoc(aux1, gLnk("R", "AlphaFMM", "vars/Hamiltonian.html#AlphaFMM"))
 insDoc(aux1, gLnk("R", "AnimationMultiFiles", "vars/Utilities.html#AnimationMultiFiles"))
@@ -52,7 +55,6 @@ insDoc(aux1, gLnk("R", "CasidaSpectrumMinEnergy", "vars/Utilities.html#CasidaSpe
 insDoc(aux1, gLnk("R", "CasidaSpectrumRotationMatrix", "vars/Utilities.html#CasidaSpectrumRotationMatrix"))
 insDoc(aux1, gLnk("R", "CasidaTheoryLevel", "vars/Linear_Response.html#CasidaTheoryLevel"))
 insDoc(aux1, gLnk("R", "CasidaTransitionDensities", "vars/Linear_Response.html#CasidaTransitionDensities"))
-insDoc(aux1, gLnk("R", "CavityGeometry", "vars/Hamiltonian.html#CavityGeometry"))
 insDoc(aux1, gLnk("R", "ClassicalPotential", "vars/Hamiltonian.html#ClassicalPotential"))
 insDoc(aux1, gLnk("R", "ComplexScaling", "vars/Hamiltonian.html#ComplexScaling"))
 insDoc(aux1, gLnk("R", "ComplexScalingAlpha", "vars/Hamiltonian.html#ComplexScalingAlpha"))
@@ -63,22 +65,28 @@ insDoc(aux1, gLnk("R", "ComplexScalingLocalizedStates", "vars/Hamiltonian.html#C
 insDoc(aux1, gLnk("R", "ComplexScalingPenalizationFactor", "vars/Hamiltonian.html#ComplexScalingPenalizationFactor"))
 insDoc(aux1, gLnk("R", "ComplexScalingRotateSpectrum", "vars/Hamiltonian.html#ComplexScalingRotateSpectrum"))
 insDoc(aux1, gLnk("R", "ComplexScalingTheta", "vars/Hamiltonian.html#ComplexScalingTheta"))
+insDoc(aux1, gLnk("R", "ConductivitySpectrumTimeStepFactor", "vars/Utilities.html#ConductivitySpectrumTimeStepFactor"))
 insDoc(aux1, gLnk("R", "ConvAbsDens", "vars/SCF.html#ConvAbsDens"))
 insDoc(aux1, gLnk("R", "ConvAbsEv", "vars/SCF.html#ConvAbsEv"))
 insDoc(aux1, gLnk("R", "ConvEigenError", "vars/SCF.html#ConvEigenError"))
 insDoc(aux1, gLnk("R", "ConvertEnd", "vars/Utilities.html#ConvertEnd"))
 insDoc(aux1, gLnk("R", "ConvertEnergyMax", "vars/Utilities.html#ConvertEnergyMax"))
 insDoc(aux1, gLnk("R", "ConvertEnergyMin", "vars/Utilities.html#ConvertEnergyMin"))
+insDoc(aux1, gLnk("R", "ConvertEnergyStep", "vars/Utilities.html#ConvertEnergyStep"))
 insDoc(aux1, gLnk("R", "ConvertFilename", "vars/Utilities.html#ConvertFilename"))
 insDoc(aux1, gLnk("R", "ConvertFolder", "vars/Utilities.html#ConvertFolder"))
+insDoc(aux1, gLnk("R", "ConvertFTMethod", "vars/Utilities.html#ConvertFTMethod"))
+insDoc(aux1, gLnk("R", "ConvertHow", "vars/Utilities.html#ConvertHow"))
 insDoc(aux1, gLnk("R", "ConvertIterateFolder", "vars/Utilities.html#ConvertIterateFolder"))
+insDoc(aux1, gLnk("R", "ConvertOutputFilename", "vars/Utilities.html#ConvertOutputFilename"))
+insDoc(aux1, gLnk("R", "ConvertOutputFolder", "vars/Utilities.html#ConvertOutputFolder"))
 insDoc(aux1, gLnk("R", "ConvertReadSize", "vars/Utilities.html#ConvertReadSize"))
+insDoc(aux1, gLnk("R", "ConvertScalarOperation", "vars/Utilities.html#ConvertScalarOperation"))
 insDoc(aux1, gLnk("R", "ConvertStart", "vars/Utilities.html#ConvertStart"))
 insDoc(aux1, gLnk("R", "ConvertStep", "vars/Utilities.html#ConvertStep"))
 insDoc(aux1, gLnk("R", "ConvertSubtract", "vars/Utilities.html#ConvertSubtract"))
 insDoc(aux1, gLnk("R", "ConvertSubtractFilename", "vars/Utilities.html#ConvertSubtractFilename"))
 insDoc(aux1, gLnk("R", "ConvertSubtractFolder", "vars/Utilities.html#ConvertSubtractFolder"))
-insDoc(aux1, gLnk("R", "ConvertTransform", "vars/Utilities.html#ConvertTransform"))
 insDoc(aux1, gLnk("R", "ConvForce", "vars/SCF.html#ConvForce"))
 insDoc(aux1, gLnk("R", "ConvRelDens", "vars/SCF.html#ConvRelDens"))
 insDoc(aux1, gLnk("R", "ConvRelEv", "vars/SCF.html#ConvRelEv"))
@@ -94,7 +102,7 @@ insDoc(aux1, gLnk("R", "CurvModineJlocal", "vars/Mesh.html#CurvModineJlocal"))
 insDoc(aux1, gLnk("R", "CurvModineJrange", "vars/Mesh.html#CurvModineJrange"))
 insDoc(aux1, gLnk("R", "CurvModineXBar", "vars/Mesh.html#CurvModineXBar"))
 aux1 = insFld(aux0, gFld("D", "javascript:parent.op()"))
-insDoc(aux1, gLnk("R", "DebugLevel", "vars/Execution.html#DebugLevel"))
+insDoc(aux1, gLnk("R", "Debug", "vars/Execution.html#Debug"))
 insDoc(aux1, gLnk("R", "DegeneracyThreshold", "vars/States.html#DegeneracyThreshold"))
 insDoc(aux1, gLnk("R", "DeltaEFMM", "vars/Hamiltonian.html#DeltaEFMM"))
 insDoc(aux1, gLnk("R", "DensitytoCalc", "vars/States.html#DensitytoCalc"))
@@ -125,12 +133,14 @@ insDoc(aux1, gLnk("R", "EigensolverTolerance", "vars/SCF.html#EigensolverToleran
 insDoc(aux1, gLnk("R", "ELFWithCurrentTerm", "vars/Output.html#ELFWithCurrentTerm"))
 insDoc(aux1, gLnk("R", "EMCalcBornCharges", "vars/Linear_Response.html#EMCalcBornCharges"))
 insDoc(aux1, gLnk("R", "EMCalcDiagonalField", "vars/Linear_Response.html#EMCalcDiagonalField"))
+insDoc(aux1, gLnk("R", "EMCalcMagnetooptics", "vars/Linear_Response.html#EMCalcMagnetooptics"))
 insDoc(aux1, gLnk("R", "EMCalcRotatoryResponse", "vars/Linear_Response.html#EMCalcRotatoryResponse"))
 insDoc(aux1, gLnk("R", "EMEta", "vars/Linear_Response.html#EMEta"))
 insDoc(aux1, gLnk("R", "EMForceNoKdotP", "vars/Linear_Response.html#EMForceNoKdotP"))
 insDoc(aux1, gLnk("R", "EMFreqs", "vars/Linear_Response.html#EMFreqs"))
 insDoc(aux1, gLnk("R", "EMFreqsSort", "vars/Linear_Response.html#EMFreqsSort"))
 insDoc(aux1, gLnk("R", "EMHyperpol", "vars/Linear_Response.html#EMHyperpol"))
+insDoc(aux1, gLnk("R", "EMMagnetoopticsNoHVar", "vars/Linear_Response.html#EMMagnetoopticsNoHVar"))
 insDoc(aux1, gLnk("R", "EMOccupiedResponse", "vars/Linear_Response.html#EMOccupiedResponse"))
 insDoc(aux1, gLnk("R", "EMPerturbationType", "vars/Linear_Response.html#EMPerturbationType"))
 insDoc(aux1, gLnk("R", "EMStartDensityIsZeroField", "vars/Linear_Response.html#EMStartDensityIsZeroField"))
@@ -138,6 +148,7 @@ insDoc(aux1, gLnk("R", "EMStaticElectricField", "vars/Linear_Response.html#EMSta
 insDoc(aux1, gLnk("R", "EMVerbose", "vars/Linear_Response.html#EMVerbose"))
 insDoc(aux1, gLnk("R", "EMWavefunctionsFromScratch", "vars/Linear_Response.html#EMWavefunctionsFromScratch"))
 insDoc(aux1, gLnk("R", "EMWriteRestartDensities", "vars/Linear_Response.html#EMWriteRestartDensities"))
+insDoc(aux1, gLnk("R", "EwaldAlpha", "vars/Hamiltonian.html#EwaldAlpha"))
 insDoc(aux1, gLnk("R", "ExcessCharge", "vars/States.html#ExcessCharge"))
 insDoc(aux1, gLnk("R", "ExperimentalFeatures", "vars/Execution.html#ExperimentalFeatures"))
 insDoc(aux1, gLnk("R", "ExtraStates", "vars/States.html#ExtraStates"))
@@ -152,10 +163,13 @@ insDoc(aux1, gLnk("R", "FlushMessages", "vars/Execution.html#FlushMessages"))
 insDoc(aux1, gLnk("R", "ForceComplex", "vars/Execution.html#ForceComplex"))
 insDoc(aux1, gLnk("R", "ForceTotalEnforce", "vars/Hamiltonian.html#ForceTotalEnforce"))
 insDoc(aux1, gLnk("R", "FromScratch", "vars/Execution.html#FromScratch"))
+insDoc(aux1, gLnk("R", "FrozenDir", "vars/Output.html#FrozenDir"))
+insDoc(aux1, gLnk("R", "FrozenStates", "vars/Output.html#FrozenStates"))
 aux1 = insFld(aux0, gFld("G", "javascript:parent.op()"))
+insDoc(aux1, gLnk("R", "GaugeFieldDynamics", "vars/Hamiltonian.html#GaugeFieldDynamics"))
 insDoc(aux1, gLnk("R", "GaugeVectorField", "vars/Hamiltonian.html#GaugeVectorField"))
-insDoc(aux1, gLnk("R", "GCMSlaterDeterminants", "vars/Calculation_Modes.html#GCMSlaterDeterminants"))
 insDoc(aux1, gLnk("R", "GOCenter", "vars/Calculation_Modes.html#GOCenter"))
+insDoc(aux1, gLnk("R", "GOFireMass", "vars/Calculation_Modes.html#GOFireMass"))
 insDoc(aux1, gLnk("R", "GOLineTol", "vars/Calculation_Modes.html#GOLineTol"))
 insDoc(aux1, gLnk("R", "GOMaxIter", "vars/Calculation_Modes.html#GOMaxIter"))
 insDoc(aux1, gLnk("R", "GOMethod", "vars/Calculation_Modes.html#GOMethod"))
@@ -173,8 +187,8 @@ insDoc(aux1, gLnk("R", "InitialSpins", "vars/States.html#InitialSpins"))
 insDoc(aux1, gLnk("R", "Interaction1D", "vars/Hamiltonian.html#Interaction1D"))
 insDoc(aux1, gLnk("R", "Interaction1DScreening", "vars/Hamiltonian.html#Interaction1DScreening"))
 insDoc(aux1, gLnk("R", "InvertKSConvAbsDens", "vars/Calculation_Modes.html#InvertKSConvAbsDens"))
+insDoc(aux1, gLnk("R", "InvertKSMaxIter", "vars/Calculation_Modes.html#InvertKSMaxIter"))
 insDoc(aux1, gLnk("R", "InvertKSmethod", "vars/Calculation_Modes.html#InvertKSmethod"))
-insDoc(aux1, gLnk("R", "InvertKSStabilizer", "vars/Calculation_Modes.html#InvertKSStabilizer"))
 insDoc(aux1, gLnk("R", "InvertKSTargetDensity", "vars/Calculation_Modes.html#InvertKSTargetDensity"))
 insDoc(aux1, gLnk("R", "InvertKSVerbosity", "vars/Calculation_Modes.html#InvertKSVerbosity"))
 insDoc(aux1, gLnk("R", "IonicInteraction", "vars/System.html#IonicInteraction"))
@@ -185,11 +199,13 @@ insDoc(aux1, gLnk("R", "KdotPCalculateEffectiveMasses", "vars/Linear_Response.ht
 insDoc(aux1, gLnk("R", "KdotPEta", "vars/Linear_Response.html#KdotPEta"))
 insDoc(aux1, gLnk("R", "KdotPOccupiedSolutionMethod", "vars/Linear_Response.html#KdotPOccupiedSolutionMethod"))
 insDoc(aux1, gLnk("R", "KdotPUseNonLocalPseudopotential", "vars/Linear_Response.html#KdotPUseNonLocalPseudopotential"))
+insDoc(aux1, gLnk("R", "KdotPVelMethod", "vars/Linear_Response.html#KdotPVelMethod"))
 insDoc(aux1, gLnk("R", "KPoints", "vars/Mesh.html#KPoints"))
 insDoc(aux1, gLnk("R", "KPointsGrid", "vars/Mesh.html#KPointsGrid"))
 insDoc(aux1, gLnk("R", "KPointsReduced", "vars/Mesh.html#KPointsReduced"))
 insDoc(aux1, gLnk("R", "KPointsUseSymmetries", "vars/Mesh.html#KPointsUseSymmetries"))
 insDoc(aux1, gLnk("R", "KPointsUseTimeReversal", "vars/Mesh.html#KPointsUseTimeReversal"))
+insDoc(aux1, gLnk("R", "KSInversionAsymptotics", "vars/Calculation_Modes.html#KSInversionAsymptotics"))
 insDoc(aux1, gLnk("R", "KSInversionLevel", "vars/Calculation_Modes.html#KSInversionLevel"))
 aux1 = insFld(aux0, gFld("L", "javascript:parent.op()"))
 insDoc(aux1, gLnk("R", "LatticeVectors", "vars/Mesh.html#LatticeVectors"))
@@ -205,21 +221,25 @@ insDoc(aux1, gLnk("R", "LCAOMaximumOrbitalRadius", "vars/SCF.html#LCAOMaximumOrb
 insDoc(aux1, gLnk("R", "LCAOScaleFactor", "vars/SCF.html#LCAOScaleFactor"))
 insDoc(aux1, gLnk("R", "LCAOStart", "vars/SCF.html#LCAOStart"))
 insDoc(aux1, gLnk("R", "LDBaderThreshold", "vars/Utilities.html#LDBaderThreshold"))
+insDoc(aux1, gLnk("R", "LDEnd", "vars/Utilities.html#LDEnd"))
 insDoc(aux1, gLnk("R", "LDExtraWrite", "vars/Utilities.html#LDExtraWrite"))
 insDoc(aux1, gLnk("R", "LDFilename", "vars/Utilities.html#LDFilename"))
 insDoc(aux1, gLnk("R", "LDFolder", "vars/Utilities.html#LDFolder"))
+insDoc(aux1, gLnk("R", "LDIterateFolder", "vars/Utilities.html#LDIterateFolder"))
 insDoc(aux1, gLnk("R", "LDMultipoleLmax", "vars/Utilities.html#LDMultipoleLmax"))
 insDoc(aux1, gLnk("R", "LDOutput", "vars/Utilities.html#LDOutput"))
-insDoc(aux1, gLnk("R", "LDOutputHow", "vars/Utilities.html#LDOutputHow"))
+insDoc(aux1, gLnk("R", "LDOutputFormat", "vars/Utilities.html#LDOutputFormat"))
 insDoc(aux1, gLnk("R", "LDOverWrite", "vars/Utilities.html#LDOverWrite"))
 insDoc(aux1, gLnk("R", "LDRadiiFile", "vars/Utilities.html#LDRadiiFile"))
+insDoc(aux1, gLnk("R", "LDRestart", "vars/Utilities.html#LDRestart"))
+insDoc(aux1, gLnk("R", "LDRestartFolder", "vars/Utilities.html#LDRestartFolder"))
+insDoc(aux1, gLnk("R", "LDStart", "vars/Utilities.html#LDStart"))
+insDoc(aux1, gLnk("R", "LDStep", "vars/Utilities.html#LDStep"))
 insDoc(aux1, gLnk("R", "LDUpdate", "vars/Utilities.html#LDUpdate"))
+insDoc(aux1, gLnk("R", "LDUseAtomicRadii", "vars/Utilities.html#LDUseAtomicRadii"))
 insDoc(aux1, gLnk("R", "LinearSolver", "vars/Linear_Response.html#LinearSolver"))
 insDoc(aux1, gLnk("R", "LinearSolverMaxIter", "vars/Linear_Response.html#LinearSolverMaxIter"))
-insDoc(aux1, gLnk("R", "LiquidDensity", "vars/Utilities.html#LiquidDensity"))
-insDoc(aux1, gLnk("R", "LiquidMoleculeScale", "vars/Utilities.html#LiquidMoleculeScale"))
-insDoc(aux1, gLnk("R", "LiquidNumberOfMolecules", "vars/Utilities.html#LiquidNumberOfMolecules"))
-insDoc(aux1, gLnk("R", "LocalDomain", "vars/Utilities.html#LocalDomain"))
+insDoc(aux1, gLnk("R", "LocalDomains", "vars/Utilities.html#LocalDomains"))
 insDoc(aux1, gLnk("R", "LocalMagneticMomentsSphereRadius", "vars/Output.html#LocalMagneticMomentsSphereRadius"))
 insDoc(aux1, gLnk("R", "LRConvAbsDens", "vars/Linear_Response.html#LRConvAbsDens"))
 insDoc(aux1, gLnk("R", "LRConvRelDens", "vars/Linear_Response.html#LRConvRelDens"))
@@ -237,8 +257,6 @@ insDoc(aux1, gLnk("R", "MassScaling", "vars/Hamiltonian.html#MassScaling"))
 insDoc(aux1, gLnk("R", "MaximumIter", "vars/SCF.html#MaximumIter"))
 insDoc(aux1, gLnk("R", "MaximumIterBerry", "vars/SCF.html#MaximumIterBerry"))
 insDoc(aux1, gLnk("R", "MemoryLimit", "vars/Execution.html#MemoryLimit"))
-insDoc(aux1, gLnk("R", "MemoryMaxIter", "vars/Time-Dependent.html#MemoryMaxIter"))
-insDoc(aux1, gLnk("R", "MemoryTol", "vars/Time-Dependent.html#MemoryTol"))
 insDoc(aux1, gLnk("R", "MeshBlockSize", "vars/Execution.html#MeshBlockSize"))
 insDoc(aux1, gLnk("R", "MeshOrder", "vars/Execution.html#MeshOrder"))
 insDoc(aux1, gLnk("R", "MeshPartition", "vars/Execution.html#MeshPartition"))
@@ -251,6 +269,7 @@ insDoc(aux1, gLnk("R", "MeshPartitionWrite", "vars/Execution.html#MeshPartitionW
 insDoc(aux1, gLnk("R", "MeshUseTopology", "vars/Execution.html#MeshUseTopology"))
 insDoc(aux1, gLnk("R", "MixField", "vars/SCF.html#MixField"))
 insDoc(aux1, gLnk("R", "Mixing", "vars/SCF.html#Mixing"))
+insDoc(aux1, gLnk("R", "MixingScheme", "vars/SCF.html#MixingScheme"))
 insDoc(aux1, gLnk("R", "MixNumberSteps", "vars/SCF.html#MixNumberSteps"))
 insDoc(aux1, gLnk("R", "MomentumTransfer", "vars/Output.html#MomentumTransfer"))
 insDoc(aux1, gLnk("R", "MoveIons", "vars/Time-Dependent.html#MoveIons"))
@@ -314,56 +333,87 @@ insDoc(aux1, gLnk("R", "OCTVelocityTarget", "vars/Calculation_Modes.html#OCTVelo
 insDoc(aux1, gLnk("R", "OEPLevel", "vars/Hamiltonian.html#OEPLevel"))
 insDoc(aux1, gLnk("R", "OEPMixing", "vars/Hamiltonian.html#OEPMixing"))
 insDoc(aux1, gLnk("R", "OnlyUserDefinedInitialStates", "vars/States.html#OnlyUserDefinedInitialStates"))
-insDoc(aux1, gLnk("R", "OpenBoundaries", "vars/Mesh.html#OpenBoundaries"))
-insDoc(aux1, gLnk("R", "OpenBoundariesAdditionalTerms", "vars/Open_Boundaries.html#OpenBoundariesAdditionalTerms"))
-insDoc(aux1, gLnk("R", "OpenBoundariesMaxMemCoeffs", "vars/Open_Boundaries.html#OpenBoundariesMaxMemCoeffs"))
-insDoc(aux1, gLnk("R", "OpenBoundariesMemType", "vars/Open_Boundaries.html#OpenBoundariesMemType"))
-insDoc(aux1, gLnk("R", "OpenBoundariesQMRMaxIter", "vars/Open_Boundaries.html#OpenBoundariesQMRMaxIter"))
-insDoc(aux1, gLnk("R", "OpenBoundariesQMRTol", "vars/Open_Boundaries.html#OpenBoundariesQMRTol"))
 insDoc(aux1, gLnk("R", "OpenCLBenchmark", "vars/Execution.html#OpenCLBenchmark"))
 insDoc(aux1, gLnk("R", "OpenCLDevice", "vars/Execution.html#OpenCLDevice"))
 insDoc(aux1, gLnk("R", "OpenCLPlatform", "vars/Execution.html#OpenCLPlatform"))
 insDoc(aux1, gLnk("R", "OpenSCADIsovalue", "vars/Output.html#OpenSCADIsovalue"))
 insDoc(aux1, gLnk("R", "OperateComplex", "vars/Execution.html#OperateComplex"))
+insDoc(aux1, gLnk("R", "OperateComplexSingle", "vars/Execution.html#OperateComplexSingle"))
 insDoc(aux1, gLnk("R", "OperateDouble", "vars/Execution.html#OperateDouble"))
 insDoc(aux1, gLnk("R", "OperateOpenCL", "vars/Execution.html#OperateOpenCL"))
+insDoc(aux1, gLnk("R", "OperateSingle", "vars/Execution.html#OperateSingle"))
 insDoc(aux1, gLnk("R", "Output", "vars/Output.html#Output"))
 insDoc(aux1, gLnk("R", "OutputBandsGnuplotMode", "vars/Output.html#OutputBandsGnuplotMode"))
 insDoc(aux1, gLnk("R", "OutputBandsGraceMode", "vars/Output.html#OutputBandsGraceMode"))
 insDoc(aux1, gLnk("R", "OutputDuringSCF", "vars/Output.html#OutputDuringSCF"))
-insDoc(aux1, gLnk("R", "OutputHow", "vars/Output.html#OutputHow"))
+insDoc(aux1, gLnk("R", "OutputFormat", "vars/Output.html#OutputFormat"))
 insDoc(aux1, gLnk("R", "OutputInterval", "vars/Output.html#OutputInterval"))
 insDoc(aux1, gLnk("R", "OutputIterDir", "vars/Output.html#OutputIterDir"))
 insDoc(aux1, gLnk("R", "OutputMatrixElements", "vars/Output.html#OutputMatrixElements"))
 insDoc(aux1, gLnk("R", "OutputMEMultipoles", "vars/Output.html#OutputMEMultipoles"))
 insDoc(aux1, gLnk("R", "OutputWfsNumber", "vars/Output.html#OutputWfsNumber"))
 aux1 = insFld(aux0, gFld("P", "javascript:parent.op()"))
-insDoc(aux1, gLnk("R", "ParallelizationGroupRanks", "vars/Execution.html#ParallelizationGroupRanks"))
 insDoc(aux1, gLnk("R", "ParallelizationNumberSlaves", "vars/Execution.html#ParallelizationNumberSlaves"))
 insDoc(aux1, gLnk("R", "ParallelizationOfDerivatives", "vars/Execution.html#ParallelizationOfDerivatives"))
 insDoc(aux1, gLnk("R", "ParallelizationPoissonAllNodes", "vars/Execution.html#ParallelizationPoissonAllNodes"))
-insDoc(aux1, gLnk("R", "ParallelizationStrategy", "vars/Execution.html#ParallelizationStrategy"))
+insDoc(aux1, gLnk("R", "ParDomains", "vars/Execution.html#ParDomains"))
+insDoc(aux1, gLnk("R", "ParKPoints", "vars/Execution.html#ParKPoints"))
+insDoc(aux1, gLnk("R", "ParOther", "vars/Execution.html#ParOther"))
+insDoc(aux1, gLnk("R", "ParStates", "vars/Execution.html#ParStates"))
 insDoc(aux1, gLnk("R", "ParticleMass", "vars/Hamiltonian.html#ParticleMass"))
 insDoc(aux1, gLnk("R", "PartitionPrint", "vars/Execution.html#PartitionPrint"))
+insDoc(aux1, gLnk("R", "PCMCalcMethod", "vars/Hamiltonian.html#PCMCalcMethod"))
+insDoc(aux1, gLnk("R", "PCMCalculation", "vars/Hamiltonian.html#PCMCalculation"))
+insDoc(aux1, gLnk("R", "PCMCavity", "vars/Hamiltonian.html#PCMCavity"))
+insDoc(aux1, gLnk("R", "PCMChargeSmearNN", "vars/Hamiltonian.html#PCMChargeSmearNN"))
+insDoc(aux1, gLnk("R", "PCMDynamicEpsilon", "vars/Hamiltonian.html#PCMDynamicEpsilon"))
+insDoc(aux1, gLnk("R", "PCMGamessBenchmark", "vars/Hamiltonian.html#PCMGamessBenchmark"))
+insDoc(aux1, gLnk("R", "PCMRadiusScaling", "vars/Hamiltonian.html#PCMRadiusScaling"))
+insDoc(aux1, gLnk("R", "PCMSmearingFactor", "vars/Hamiltonian.html#PCMSmearingFactor"))
+insDoc(aux1, gLnk("R", "PCMSpheresOnH", "vars/Hamiltonian.html#PCMSpheresOnH"))
+insDoc(aux1, gLnk("R", "PCMStaticEpsilon", "vars/Hamiltonian.html#PCMStaticEpsilon"))
+insDoc(aux1, gLnk("R", "PCMTessSubdivider", "vars/Hamiltonian.html#PCMTessSubdivider"))
+insDoc(aux1, gLnk("R", "PCMUpdateIter", "vars/Hamiltonian.html#PCMUpdateIter"))
+insDoc(aux1, gLnk("R", "PCMVdWRadii", "vars/Hamiltonian.html#PCMVdWRadii"))
 insDoc(aux1, gLnk("R", "PDBClassical", "vars/System.html#PDBClassical"))
 insDoc(aux1, gLnk("R", "PDBCoordinates", "vars/System.html#PDBCoordinates"))
 insDoc(aux1, gLnk("R", "PDBVelocities", "vars/System.html#PDBVelocities"))
 insDoc(aux1, gLnk("R", "PeriodicDimensions", "vars/System.html#PeriodicDimensions"))
+insDoc(aux1, gLnk("R", "PES_Flux_DeltaK", "vars/Time-Dependent.html#PES_Flux_DeltaK"))
+insDoc(aux1, gLnk("R", "PES_Flux_Kmax", "vars/Time-Dependent.html#PES_Flux_Kmax"))
+insDoc(aux1, gLnk("R", "PES_Flux_Lmax", "vars/Time-Dependent.html#PES_Flux_Lmax"))
+insDoc(aux1, gLnk("R", "PES_Flux_Lsize", "vars/Time-Dependent.html#PES_Flux_Lsize"))
+insDoc(aux1, gLnk("R", "PES_Flux_Offset", "vars/Time-Dependent.html#PES_Flux_Offset"))
+insDoc(aux1, gLnk("R", "PES_Flux_Radius", "vars/Time-Dependent.html#PES_Flux_Radius"))
+insDoc(aux1, gLnk("R", "PES_Flux_Shape", "vars/Time-Dependent.html#PES_Flux_Shape"))
+insDoc(aux1, gLnk("R", "PES_Flux_StepsPhiK", "vars/Time-Dependent.html#PES_Flux_StepsPhiK"))
+insDoc(aux1, gLnk("R", "PES_Flux_StepsPhiR", "vars/Time-Dependent.html#PES_Flux_StepsPhiR"))
+insDoc(aux1, gLnk("R", "PES_Flux_StepsThetaK", "vars/Time-Dependent.html#PES_Flux_StepsThetaK"))
+insDoc(aux1, gLnk("R", "PES_Flux_StepsThetaR", "vars/Time-Dependent.html#PES_Flux_StepsThetaR"))
+insDoc(aux1, gLnk("R", "PES_Flux_TDSteps", "vars/Time-Dependent.html#PES_Flux_TDSteps"))
+insDoc(aux1, gLnk("R", "PES_Flux_TDStepsInterval", "vars/Time-Dependent.html#PES_Flux_TDStepsInterval"))
+insDoc(aux1, gLnk("R", "PES_Flux_UseMemory", "vars/Time-Dependent.html#PES_Flux_UseMemory"))
+insDoc(aux1, gLnk("R", "PES_spm_DeltaOmega", "vars/Time-Dependent.html#PES_spm_DeltaOmega"))
+insDoc(aux1, gLnk("R", "PES_spm_OmegaMax", "vars/Time-Dependent.html#PES_spm_OmegaMax"))
+insDoc(aux1, gLnk("R", "PES_spm_points", "vars/Time-Dependent.html#PES_spm_points"))
+insDoc(aux1, gLnk("R", "PES_spm_Radius", "vars/Time-Dependent.html#PES_spm_Radius"))
+insDoc(aux1, gLnk("R", "PES_spm_recipe", "vars/Time-Dependent.html#PES_spm_recipe"))
+insDoc(aux1, gLnk("R", "PES_spm_StepsPhiR", "vars/Time-Dependent.html#PES_spm_StepsPhiR"))
+insDoc(aux1, gLnk("R", "PES_spm_StepsThetaR", "vars/Time-Dependent.html#PES_spm_StepsThetaR"))
 insDoc(aux1, gLnk("R", "PESMask2PEnlargeFactor", "vars/Time-Dependent.html#PESMask2PEnlargeFactor"))
 insDoc(aux1, gLnk("R", "PESMaskEnlargeFactor", "vars/Time-Dependent.html#PESMaskEnlargeFactor"))
 insDoc(aux1, gLnk("R", "PESMaskFilterCutOff", "vars/Time-Dependent.html#PESMaskFilterCutOff"))
 insDoc(aux1, gLnk("R", "PESMaskIncludePsiA", "vars/Time-Dependent.html#PESMaskIncludePsiA"))
 insDoc(aux1, gLnk("R", "PESMaskMode", "vars/Time-Dependent.html#PESMaskMode"))
-insDoc(aux1, gLnk("R", "PESMaskOutputInterpolate", "vars/Time-Dependent.html#PESMaskOutputInterpolate"))
 insDoc(aux1, gLnk("R", "PESMaskPlaneWaveProjection", "vars/Time-Dependent.html#PESMaskPlaneWaveProjection"))
-insDoc(aux1, gLnk("R", "PESMaskPropagator", "vars/Time-Dependent.html#PESMaskPropagator"))
 insDoc(aux1, gLnk("R", "PESMaskShape", "vars/Time-Dependent.html#PESMaskShape"))
 insDoc(aux1, gLnk("R", "PESMaskSize", "vars/Time-Dependent.html#PESMaskSize"))
 insDoc(aux1, gLnk("R", "PESMaskSpectEnergyMax", "vars/Time-Dependent.html#PESMaskSpectEnergyMax"))
 insDoc(aux1, gLnk("R", "PESMaskSpectEnergyStep", "vars/Time-Dependent.html#PESMaskSpectEnergyStep"))
 insDoc(aux1, gLnk("R", "PESMaskStartTime", "vars/Time-Dependent.html#PESMaskStartTime"))
 insDoc(aux1, gLnk("R", "PhotoElectronSpectrum", "vars/Time-Dependent.html#PhotoElectronSpectrum"))
-insDoc(aux1, gLnk("R", "PhotoElectronSpectrumPoints", "vars/Time-Dependent.html#PhotoElectronSpectrumPoints"))
+insDoc(aux1, gLnk("R", "PhotoelectronSpectrumOutput", "vars/Utilities.html#PhotoelectronSpectrumOutput"))
+insDoc(aux1, gLnk("R", "PhotoelectronSpectrumResolveStates", "vars/Utilities.html#PhotoelectronSpectrumResolveStates"))
 insDoc(aux1, gLnk("R", "PNFFTCutoff", "vars/Mesh.html#PNFFTCutoff"))
 insDoc(aux1, gLnk("R", "PNFFTOversampling", "vars/Mesh.html#PNFFTOversampling"))
 insDoc(aux1, gLnk("R", "Poisson1DSoftCoulombParam", "vars/Hamiltonian.html#Poisson1DSoftCoulombParam"))
@@ -391,15 +441,16 @@ insDoc(aux1, gLnk("R", "PropagationSpectrumDampMode", "vars/Utilities.html#Propa
 insDoc(aux1, gLnk("R", "PropagationSpectrumEndTime", "vars/Utilities.html#PropagationSpectrumEndTime"))
 insDoc(aux1, gLnk("R", "PropagationSpectrumEnergyStep", "vars/Utilities.html#PropagationSpectrumEnergyStep"))
 insDoc(aux1, gLnk("R", "PropagationSpectrumMaxEnergy", "vars/Utilities.html#PropagationSpectrumMaxEnergy"))
+insDoc(aux1, gLnk("R", "PropagationSpectrumSigmaDiagonalization", "vars/Utilities.html#PropagationSpectrumSigmaDiagonalization"))
 insDoc(aux1, gLnk("R", "PropagationSpectrumStartTime", "vars/Utilities.html#PropagationSpectrumStartTime"))
 insDoc(aux1, gLnk("R", "PropagationSpectrumTransform", "vars/Utilities.html#PropagationSpectrumTransform"))
 insDoc(aux1, gLnk("R", "PropagationSpectrumType", "vars/Utilities.html#PropagationSpectrumType"))
+insDoc(aux1, gLnk("R", "PseudopotentialSet", "vars/System.html#PseudopotentialSet"))
 aux1 = insFld(aux0, gFld("R", "javascript:parent.op()"))
 insDoc(aux1, gLnk("R", "Radius", "vars/Mesh.html#Radius"))
 insDoc(aux1, gLnk("R", "RandomVelocityTemp", "vars/System.html#RandomVelocityTemp"))
 insDoc(aux1, gLnk("R", "RashbaSpinOrbitCoupling", "vars/Hamiltonian.html#RashbaSpinOrbitCoupling"))
 insDoc(aux1, gLnk("R", "RDMConvEner", "vars/SCF.html#RDMConvEner"))
-insDoc(aux1, gLnk("R", "RDMMaxIter", "vars/SCF.html#RDMMaxIter"))
 insDoc(aux1, gLnk("R", "RDMTolerance", "vars/SCF.html#RDMTolerance"))
 insDoc(aux1, gLnk("R", "RecalculateGSDuringEvolution", "vars/Time-Dependent.html#RecalculateGSDuringEvolution"))
 insDoc(aux1, gLnk("R", "ReducedCoordinates", "vars/System.html#ReducedCoordinates"))
@@ -419,16 +470,17 @@ insDoc(aux1, gLnk("R", "RootSolverRelTolerance", "vars/Math.html#RootSolverRelTo
 insDoc(aux1, gLnk("R", "RootSolverWSRadius", "vars/Math.html#RootSolverWSRadius"))
 aux1 = insFld(aux0, gFld("S", "javascript:parent.op()"))
 insDoc(aux1, gLnk("R", "ScaLAPACKCompatible", "vars/Execution.html#ScaLAPACKCompatible"))
+insDoc(aux1, gLnk("R", "SCDM_EXX", "vars/Hamiltonian.html#SCDM_EXX"))
+insDoc(aux1, gLnk("R", "SCDM_verbose", "vars/Hamiltonian.html#SCDM_verbose"))
+insDoc(aux1, gLnk("R", "SCDMCutoffRadius", "vars/Hamiltonian.html#SCDMCutoffRadius"))
 insDoc(aux1, gLnk("R", "SCFCalculateDipole", "vars/SCF.html#SCFCalculateDipole"))
 insDoc(aux1, gLnk("R", "SCFCalculateForces", "vars/SCF.html#SCFCalculateForces"))
+insDoc(aux1, gLnk("R", "SCFCalculatePartialCharges", "vars/SCF.html#SCFCalculatePartialCharges"))
 insDoc(aux1, gLnk("R", "SCFinLCAO", "vars/SCF.html#SCFinLCAO"))
 insDoc(aux1, gLnk("R", "SICCorrection", "vars/Hamiltonian.html#SICCorrection"))
 insDoc(aux1, gLnk("R", "Smearing", "vars/States.html#Smearing"))
-insDoc(aux1, gLnk("R", "SmearingFactor", "vars/Hamiltonian.html#SmearingFactor"))
 insDoc(aux1, gLnk("R", "SmearingFunction", "vars/States.html#SmearingFunction"))
 insDoc(aux1, gLnk("R", "SmearingMPOrder", "vars/States.html#SmearingMPOrder"))
-insDoc(aux1, gLnk("R", "Solvation", "vars/Hamiltonian.html#Solvation"))
-insDoc(aux1, gLnk("R", "SolventDielectricConstant", "vars/Hamiltonian.html#SolventDielectricConstant"))
 insDoc(aux1, gLnk("R", "SOStrength", "vars/Hamiltonian.html#SOStrength"))
 insDoc(aux1, gLnk("R", "Spacing", "vars/Mesh.html#Spacing"))
 insDoc(aux1, gLnk("R", "SPARSKITAbsTolerance", "vars/Math.html#SPARSKITAbsTolerance"))
@@ -454,6 +506,8 @@ insDoc(aux1, gLnk("R", "StaticMagneticField2DGauge", "vars/Hamiltonian.html#Stat
 insDoc(aux1, gLnk("R", "stderr", "vars/Execution.html#stderr"))
 insDoc(aux1, gLnk("R", "stdout", "vars/Execution.html#stdout"))
 insDoc(aux1, gLnk("R", "SubspaceDiagonalization", "vars/SCF.html#SubspaceDiagonalization"))
+insDoc(aux1, gLnk("R", "SubSystemCoordinates", "vars/System.html#SubSystemCoordinates"))
+insDoc(aux1, gLnk("R", "SubSystems", "vars/System.html#SubSystems"))
 insDoc(aux1, gLnk("R", "SymmetriesCompute", "vars/Execution.html#SymmetriesCompute"))
 insDoc(aux1, gLnk("R", "SymmetrizeDensity", "vars/States.html#SymmetrizeDensity"))
 insDoc(aux1, gLnk("R", "SymmetrizeDynamicalMatrix", "vars/Linear_Response.html#SymmetrizeDynamicalMatrix"))
@@ -472,10 +526,11 @@ insDoc(aux1, gLnk("R", "TDExternalFields", "vars/Time-Dependent.html#TDExternalF
 insDoc(aux1, gLnk("R", "TDFreezeHXC", "vars/Time-Dependent.html#TDFreezeHXC"))
 insDoc(aux1, gLnk("R", "TDFreezeOrbitals", "vars/Time-Dependent.html#TDFreezeOrbitals"))
 insDoc(aux1, gLnk("R", "TDFunctions", "vars/Time-Dependent.html#TDFunctions"))
+insDoc(aux1, gLnk("R", "TDGlobalForce", "vars/Time-Dependent.html#TDGlobalForce"))
 insDoc(aux1, gLnk("R", "TDIonicTimeScale", "vars/Time-Dependent.html#TDIonicTimeScale"))
 insDoc(aux1, gLnk("R", "TDKickFunction", "vars/Time-Dependent.html#TDKickFunction"))
 insDoc(aux1, gLnk("R", "TDLanczosTol", "vars/Time-Dependent.html#TDLanczosTol"))
-insDoc(aux1, gLnk("R", "TDMaximumIter", "vars/Time-Dependent.html#TDMaximumIter"))
+insDoc(aux1, gLnk("R", "TDMaxSteps", "vars/Time-Dependent.html#TDMaxSteps"))
 insDoc(aux1, gLnk("R", "TDMomentumTransfer", "vars/Time-Dependent.html#TDMomentumTransfer"))
 insDoc(aux1, gLnk("R", "TDMultipoleLmax", "vars/Time-Dependent.html#TDMultipoleLmax"))
 insDoc(aux1, gLnk("R", "TDOutput", "vars/Time-Dependent.html#TDOutput"))
@@ -484,31 +539,38 @@ insDoc(aux1, gLnk("R", "TDPolarizationDirection", "vars/Time-Dependent.html#TDPo
 insDoc(aux1, gLnk("R", "TDPolarizationEquivAxes", "vars/Time-Dependent.html#TDPolarizationEquivAxes"))
 insDoc(aux1, gLnk("R", "TDPolarizationWprime", "vars/Time-Dependent.html#TDPolarizationWprime"))
 insDoc(aux1, gLnk("R", "TDProjStateStart", "vars/Time-Dependent.html#TDProjStateStart"))
+insDoc(aux1, gLnk("R", "TDPropagationTime", "vars/Time-Dependent.html#TDPropagationTime"))
 insDoc(aux1, gLnk("R", "TDPropagator", "vars/Time-Dependent.html#TDPropagator"))
-insDoc(aux1, gLnk("R", "TDPSFDelta", "vars/Time-Dependent.html#TDPSFDelta"))
-insDoc(aux1, gLnk("R", "TDPSFKmin", "vars/Time-Dependent.html#TDPSFKmin"))
-insDoc(aux1, gLnk("R", "TDPSFSigma", "vars/Time-Dependent.html#TDPSFSigma"))
 insDoc(aux1, gLnk("R", "TDSCFThreshold", "vars/Time-Dependent.html#TDSCFThreshold"))
 insDoc(aux1, gLnk("R", "TDStepsWithSelfConsistency", "vars/Time-Dependent.html#TDStepsWithSelfConsistency"))
 insDoc(aux1, gLnk("R", "TDTimeStep", "vars/Time-Dependent.html#TDTimeStep"))
 insDoc(aux1, gLnk("R", "TemperatureFunction", "vars/Time-Dependent.html#TemperatureFunction"))
+insDoc(aux1, gLnk("R", "TestMaxBlockSize", "vars/Utilities.html#TestMaxBlockSize"))
+insDoc(aux1, gLnk("R", "TestMinBlockSize", "vars/Utilities.html#TestMinBlockSize"))
 insDoc(aux1, gLnk("R", "TestMode", "vars/Utilities.html#TestMode"))
+insDoc(aux1, gLnk("R", "TestRepetitions", "vars/Utilities.html#TestRepetitions"))
 insDoc(aux1, gLnk("R", "TestType", "vars/Utilities.html#TestType"))
 insDoc(aux1, gLnk("R", "TheoryLevel", "vars/Hamiltonian.html#TheoryLevel"))
 insDoc(aux1, gLnk("R", "Thermostat", "vars/Time-Dependent.html#Thermostat"))
 insDoc(aux1, gLnk("R", "ThermostatMass", "vars/Time-Dependent.html#ThermostatMass"))
+insDoc(aux1, gLnk("R", "TimeZero", "vars/Hamiltonian.html#TimeZero"))
+insDoc(aux1, gLnk("R", "TnaddFactor", "vars/Hamiltonian.html#TnaddFactor"))
+insDoc(aux1, gLnk("R", "TnaddFunctional", "vars/Hamiltonian.html#TnaddFunctional"))
+insDoc(aux1, gLnk("R", "TnaddPolarized", "vars/Hamiltonian.html#TnaddPolarized"))
 insDoc(aux1, gLnk("R", "TotalStates", "vars/States.html#TotalStates"))
 insDoc(aux1, gLnk("R", "TransformStates", "vars/States.html#TransformStates"))
-insDoc(aux1, gLnk("R", "TypeOfMixing", "vars/SCF.html#TypeOfMixing"))
 aux1 = insFld(aux0, gFld("U", "javascript:parent.op()"))
 insDoc(aux1, gLnk("R", "Units", "vars/Execution.html#Units"))
 insDoc(aux1, gLnk("R", "UnitsInput", "vars/Execution.html#UnitsInput"))
 insDoc(aux1, gLnk("R", "UnitsOutput", "vars/Execution.html#UnitsOutput"))
+insDoc(aux1, gLnk("R", "UnitsXYZFiles", "vars/Execution.html#UnitsXYZFiles"))
 insDoc(aux1, gLnk("R", "UnoccShowOccStates", "vars/Calculation_Modes.html#UnoccShowOccStates"))
 insDoc(aux1, gLnk("R", "UseFineMesh", "vars/Mesh.html#UseFineMesh"))
 insDoc(aux1, gLnk("R", "UserDefinedStates", "vars/States.html#UserDefinedStates"))
 aux1 = insFld(aux0, gFld("V", "javascript:parent.op()"))
+insDoc(aux1, gLnk("R", "VDWCorrection", "vars/Hamiltonian.html#VDWCorrection"))
 insDoc(aux1, gLnk("R", "vdWNPoints", "vars/Linear_Response.html#vdWNPoints"))
+insDoc(aux1, gLnk("R", "VDWSelfConsistent", "vars/Hamiltonian.html#VDWSelfConsistent"))
 insDoc(aux1, gLnk("R", "Velocities", "vars/System.html#Velocities"))
 insDoc(aux1, gLnk("R", "VibrationalSpectrumTime", "vars/Utilities.html#VibrationalSpectrumTime"))
 insDoc(aux1, gLnk("R", "VibrationalSpectrumTimeStepFactor", "vars/Utilities.html#VibrationalSpectrumTimeStepFactor"))
@@ -526,6 +588,7 @@ insDoc(aux1, gLnk("R", "XCDensityCorrectionOptimize", "vars/Hamiltonian.html#XCD
 insDoc(aux1, gLnk("R", "XCFunctional", "vars/Hamiltonian.html#XCFunctional"))
 insDoc(aux1, gLnk("R", "XCKernel", "vars/Hamiltonian.html#XCKernel"))
 insDoc(aux1, gLnk("R", "XCKernelLRCAlpha", "vars/Hamiltonian.html#XCKernelLRCAlpha"))
+insDoc(aux1, gLnk("R", "XCParallel", "vars/Execution.html#XCParallel"))
 insDoc(aux1, gLnk("R", "XCUseGaugeIndependentKED", "vars/Hamiltonian.html#XCUseGaugeIndependentKED"))
 insDoc(aux1, gLnk("R", "Xlength", "vars/Mesh.html#Xlength"))
 insDoc(aux1, gLnk("R", "XSFCoordinates", "vars/System.html#XSFCoordinates"))
