@@ -7,10 +7,9 @@ aux0 = gFld("Variables", "varsRightFrame.html")
 foldersTree = aux0
 aux1 = insFld(aux0, gFld("Calculation Modes", "vars/Calculation_Modes.html#Calculation_Modes"))
 insDoc(aux1, gLnk("R", "CalculationMode", "vars/Calculation_Modes.html#CalculationMode"))
-aux2 = insFld(aux1, gFld("Generator Coordinates", "vars/Calculation_Modes.html#Calculation_Modes::Generator_Coordinates"))
-insDoc(aux2, gLnk("R", "GCMSlaterDeterminants", "vars/Calculation_Modes.html#GCMSlaterDeterminants"))
 aux2 = insFld(aux1, gFld("Geometry Optimization", "vars/Calculation_Modes.html#Calculation_Modes::Geometry_Optimization"))
 insDoc(aux2, gLnk("R", "GOCenter", "vars/Calculation_Modes.html#GOCenter"))
+insDoc(aux2, gLnk("R", "GOFireMass", "vars/Calculation_Modes.html#GOFireMass"))
 insDoc(aux2, gLnk("R", "GOLineTol", "vars/Calculation_Modes.html#GOLineTol"))
 insDoc(aux2, gLnk("R", "GOMaxIter", "vars/Calculation_Modes.html#GOMaxIter"))
 insDoc(aux2, gLnk("R", "GOMethod", "vars/Calculation_Modes.html#GOMethod"))
@@ -20,10 +19,11 @@ insDoc(aux2, gLnk("R", "GOStep", "vars/Calculation_Modes.html#GOStep"))
 insDoc(aux2, gLnk("R", "GOTolerance", "vars/Calculation_Modes.html#GOTolerance"))
 aux2 = insFld(aux1, gFld("Invert KS", "vars/Calculation_Modes.html#Calculation_Modes::Invert_KS"))
 insDoc(aux2, gLnk("R", "InvertKSConvAbsDens", "vars/Calculation_Modes.html#InvertKSConvAbsDens"))
-insDoc(aux2, gLnk("R", "InvertKSStabilizer", "vars/Calculation_Modes.html#InvertKSStabilizer"))
+insDoc(aux2, gLnk("R", "InvertKSMaxIter", "vars/Calculation_Modes.html#InvertKSMaxIter"))
 insDoc(aux2, gLnk("R", "InvertKSTargetDensity", "vars/Calculation_Modes.html#InvertKSTargetDensity"))
 insDoc(aux2, gLnk("R", "InvertKSVerbosity", "vars/Calculation_Modes.html#InvertKSVerbosity"))
 insDoc(aux2, gLnk("R", "InvertKSmethod", "vars/Calculation_Modes.html#InvertKSmethod"))
+insDoc(aux2, gLnk("R", "KSInversionAsymptotics", "vars/Calculation_Modes.html#KSInversionAsymptotics"))
 insDoc(aux2, gLnk("R", "KSInversionLevel", "vars/Calculation_Modes.html#KSInversionLevel"))
 aux2 = insFld(aux1, gFld("Optimal Control", "vars/Calculation_Modes.html#Calculation_Modes::Optimal_Control"))
 insDoc(aux2, gLnk("R", "OCTCheckGradient", "vars/Calculation_Modes.html#OCTCheckGradient"))
@@ -73,7 +73,7 @@ insDoc(aux2, gLnk("R", "UnoccShowOccStates", "vars/Calculation_Modes.html#UnoccS
 aux1 = insFld(aux0, gFld("Execution", "vars/Execution.html#Execution"))
 insDoc(aux1, gLnk("R", "FromScratch", "vars/Execution.html#FromScratch"))
 aux2 = insFld(aux1, gFld("Debug", "vars/Execution.html#Execution::Debug"))
-insDoc(aux2, gLnk("R", "DebugLevel", "vars/Execution.html#DebugLevel"))
+insDoc(aux2, gLnk("R", "Debug", "vars/Execution.html#Debug"))
 insDoc(aux2, gLnk("R", "ExperimentalFeatures", "vars/Execution.html#ExperimentalFeatures"))
 insDoc(aux2, gLnk("R", "ForceComplex", "vars/Execution.html#ForceComplex"))
 insDoc(aux2, gLnk("R", "MPIDebugHook", "vars/Execution.html#MPIDebugHook"))
@@ -97,8 +97,10 @@ insDoc(aux2, gLnk("R", "MeshBlockSize", "vars/Execution.html#MeshBlockSize"))
 insDoc(aux2, gLnk("R", "MeshOrder", "vars/Execution.html#MeshOrder"))
 insDoc(aux2, gLnk("R", "NLOperatorCompactBoundaries", "vars/Execution.html#NLOperatorCompactBoundaries"))
 insDoc(aux2, gLnk("R", "OperateComplex", "vars/Execution.html#OperateComplex"))
+insDoc(aux2, gLnk("R", "OperateComplexSingle", "vars/Execution.html#OperateComplexSingle"))
 insDoc(aux2, gLnk("R", "OperateDouble", "vars/Execution.html#OperateDouble"))
 insDoc(aux2, gLnk("R", "OperateOpenCL", "vars/Execution.html#OperateOpenCL"))
+insDoc(aux2, gLnk("R", "OperateSingle", "vars/Execution.html#OperateSingle"))
 insDoc(aux2, gLnk("R", "ProfilingAllNodes", "vars/Execution.html#ProfilingAllNodes"))
 insDoc(aux2, gLnk("R", "ProfilingMode", "vars/Execution.html#ProfilingMode"))
 insDoc(aux2, gLnk("R", "StatesBlockSize", "vars/Execution.html#StatesBlockSize"))
@@ -113,25 +115,31 @@ insDoc(aux2, gLnk("R", "MeshPartitionStencil", "vars/Execution.html#MeshPartitio
 insDoc(aux2, gLnk("R", "MeshPartitionVirtualSize", "vars/Execution.html#MeshPartitionVirtualSize"))
 insDoc(aux2, gLnk("R", "MeshPartitionWrite", "vars/Execution.html#MeshPartitionWrite"))
 insDoc(aux2, gLnk("R", "MeshUseTopology", "vars/Execution.html#MeshUseTopology"))
-insDoc(aux2, gLnk("R", "ParallelizationGroupRanks", "vars/Execution.html#ParallelizationGroupRanks"))
+insDoc(aux2, gLnk("R", "ParDomains", "vars/Execution.html#ParDomains"))
+insDoc(aux2, gLnk("R", "ParKPoints", "vars/Execution.html#ParKPoints"))
+insDoc(aux2, gLnk("R", "ParOther", "vars/Execution.html#ParOther"))
+insDoc(aux2, gLnk("R", "ParStates", "vars/Execution.html#ParStates"))
 insDoc(aux2, gLnk("R", "ParallelizationNumberSlaves", "vars/Execution.html#ParallelizationNumberSlaves"))
 insDoc(aux2, gLnk("R", "ParallelizationOfDerivatives", "vars/Execution.html#ParallelizationOfDerivatives"))
 insDoc(aux2, gLnk("R", "ParallelizationPoissonAllNodes", "vars/Execution.html#ParallelizationPoissonAllNodes"))
-insDoc(aux2, gLnk("R", "ParallelizationStrategy", "vars/Execution.html#ParallelizationStrategy"))
 insDoc(aux2, gLnk("R", "PartitionPrint", "vars/Execution.html#PartitionPrint"))
 insDoc(aux2, gLnk("R", "ScaLAPACKCompatible", "vars/Execution.html#ScaLAPACKCompatible"))
+insDoc(aux2, gLnk("R", "XCParallel", "vars/Execution.html#XCParallel"))
 aux2 = insFld(aux1, gFld("Symmetries", "vars/Execution.html#Execution::Symmetries"))
 insDoc(aux2, gLnk("R", "SymmetriesCompute", "vars/Execution.html#SymmetriesCompute"))
 aux2 = insFld(aux1, gFld("Units", "vars/Execution.html#Execution::Units"))
 insDoc(aux2, gLnk("R", "Units", "vars/Execution.html#Units"))
 insDoc(aux2, gLnk("R", "UnitsInput", "vars/Execution.html#UnitsInput"))
 insDoc(aux2, gLnk("R", "UnitsOutput", "vars/Execution.html#UnitsOutput"))
+insDoc(aux2, gLnk("R", "UnitsXYZFiles", "vars/Execution.html#UnitsXYZFiles"))
 aux1 = insFld(aux0, gFld("Hamiltonian", "vars/Hamiltonian.html#Hamiltonian"))
 insDoc(aux1, gLnk("R", "CalculateSelfInducedMagneticField", "vars/Hamiltonian.html#CalculateSelfInducedMagneticField"))
 insDoc(aux1, gLnk("R", "ClassicalPotential", "vars/Hamiltonian.html#ClassicalPotential"))
 insDoc(aux1, gLnk("R", "CurrentDensity", "vars/Hamiltonian.html#CurrentDensity"))
+insDoc(aux1, gLnk("R", "EwaldAlpha", "vars/Hamiltonian.html#EwaldAlpha"))
 insDoc(aux1, gLnk("R", "FilterPotentials", "vars/Hamiltonian.html#FilterPotentials"))
 insDoc(aux1, gLnk("R", "ForceTotalEnforce", "vars/Hamiltonian.html#ForceTotalEnforce"))
+insDoc(aux1, gLnk("R", "GaugeFieldDynamics", "vars/Hamiltonian.html#GaugeFieldDynamics"))
 insDoc(aux1, gLnk("R", "GaugeVectorField", "vars/Hamiltonian.html#GaugeVectorField"))
 insDoc(aux1, gLnk("R", "GyromagneticRatio", "vars/Hamiltonian.html#GyromagneticRatio"))
 insDoc(aux1, gLnk("R", "IgnoreExternalIons", "vars/Hamiltonian.html#IgnoreExternalIons"))
@@ -139,11 +147,15 @@ insDoc(aux1, gLnk("R", "MassScaling", "vars/Hamiltonian.html#MassScaling"))
 insDoc(aux1, gLnk("R", "ParticleMass", "vars/Hamiltonian.html#ParticleMass"))
 insDoc(aux1, gLnk("R", "RashbaSpinOrbitCoupling", "vars/Hamiltonian.html#RashbaSpinOrbitCoupling"))
 insDoc(aux1, gLnk("R", "RelativisticCorrection", "vars/Hamiltonian.html#RelativisticCorrection"))
+insDoc(aux1, gLnk("R", "SCDMCutoffRadius", "vars/Hamiltonian.html#SCDMCutoffRadius"))
+insDoc(aux1, gLnk("R", "SCDM_EXX", "vars/Hamiltonian.html#SCDM_EXX"))
+insDoc(aux1, gLnk("R", "SCDM_verbose", "vars/Hamiltonian.html#SCDM_verbose"))
 insDoc(aux1, gLnk("R", "SOStrength", "vars/Hamiltonian.html#SOStrength"))
 insDoc(aux1, gLnk("R", "StaticElectricField", "vars/Hamiltonian.html#StaticElectricField"))
 insDoc(aux1, gLnk("R", "StaticMagneticField", "vars/Hamiltonian.html#StaticMagneticField"))
 insDoc(aux1, gLnk("R", "StaticMagneticField2DGauge", "vars/Hamiltonian.html#StaticMagneticField2DGauge"))
 insDoc(aux1, gLnk("R", "TheoryLevel", "vars/Hamiltonian.html#TheoryLevel"))
+insDoc(aux1, gLnk("R", "TimeZero", "vars/Hamiltonian.html#TimeZero"))
 aux2 = insFld(aux1, gFld("ComplexScaling", "vars/Hamiltonian.html#Hamiltonian::ComplexScaling"))
 insDoc(aux2, gLnk("R", "ComplexScaling", "vars/Hamiltonian.html#ComplexScaling"))
 insDoc(aux2, gLnk("R", "ComplexScalingAlpha", "vars/Hamiltonian.html#ComplexScalingAlpha"))
@@ -155,10 +167,19 @@ insDoc(aux2, gLnk("R", "ComplexScalingPenalizationFactor", "vars/Hamiltonian.htm
 insDoc(aux2, gLnk("R", "ComplexScalingRotateSpectrum", "vars/Hamiltonian.html#ComplexScalingRotateSpectrum"))
 insDoc(aux2, gLnk("R", "ComplexScalingTheta", "vars/Hamiltonian.html#ComplexScalingTheta"))
 aux2 = insFld(aux1, gFld("PCM", "vars/Hamiltonian.html#Hamiltonian::PCM"))
-insDoc(aux2, gLnk("R", "CavityGeometry", "vars/Hamiltonian.html#CavityGeometry"))
-insDoc(aux2, gLnk("R", "SmearingFactor", "vars/Hamiltonian.html#SmearingFactor"))
-insDoc(aux2, gLnk("R", "Solvation", "vars/Hamiltonian.html#Solvation"))
-insDoc(aux2, gLnk("R", "SolventDielectricConstant", "vars/Hamiltonian.html#SolventDielectricConstant"))
+insDoc(aux2, gLnk("R", "PCMCalcMethod", "vars/Hamiltonian.html#PCMCalcMethod"))
+insDoc(aux2, gLnk("R", "PCMCalculation", "vars/Hamiltonian.html#PCMCalculation"))
+insDoc(aux2, gLnk("R", "PCMCavity", "vars/Hamiltonian.html#PCMCavity"))
+insDoc(aux2, gLnk("R", "PCMChargeSmearNN", "vars/Hamiltonian.html#PCMChargeSmearNN"))
+insDoc(aux2, gLnk("R", "PCMDynamicEpsilon", "vars/Hamiltonian.html#PCMDynamicEpsilon"))
+insDoc(aux2, gLnk("R", "PCMGamessBenchmark", "vars/Hamiltonian.html#PCMGamessBenchmark"))
+insDoc(aux2, gLnk("R", "PCMRadiusScaling", "vars/Hamiltonian.html#PCMRadiusScaling"))
+insDoc(aux2, gLnk("R", "PCMSmearingFactor", "vars/Hamiltonian.html#PCMSmearingFactor"))
+insDoc(aux2, gLnk("R", "PCMSpheresOnH", "vars/Hamiltonian.html#PCMSpheresOnH"))
+insDoc(aux2, gLnk("R", "PCMStaticEpsilon", "vars/Hamiltonian.html#PCMStaticEpsilon"))
+insDoc(aux2, gLnk("R", "PCMTessSubdivider", "vars/Hamiltonian.html#PCMTessSubdivider"))
+insDoc(aux2, gLnk("R", "PCMUpdateIter", "vars/Hamiltonian.html#PCMUpdateIter"))
+insDoc(aux2, gLnk("R", "PCMVdWRadii", "vars/Hamiltonian.html#PCMVdWRadii"))
 aux2 = insFld(aux1, gFld("Poisson", "vars/Hamiltonian.html#Hamiltonian::Poisson"))
 insDoc(aux2, gLnk("R", "AlphaFMM", "vars/Hamiltonian.html#AlphaFMM"))
 insDoc(aux2, gLnk("R", "DeltaEFMM", "vars/Hamiltonian.html#DeltaEFMM"))
@@ -180,6 +201,10 @@ insDoc(aux3, gLnk("R", "PoissonSolverMGPresmoothingSteps", "vars/Hamiltonian.htm
 insDoc(aux3, gLnk("R", "PoissonSolverMGRelaxationFactor", "vars/Hamiltonian.html#PoissonSolverMGRelaxationFactor"))
 insDoc(aux3, gLnk("R", "PoissonSolverMGRelaxationMethod", "vars/Hamiltonian.html#PoissonSolverMGRelaxationMethod"))
 insDoc(aux3, gLnk("R", "PoissonSolverMGRestrictionMethod", "vars/Hamiltonian.html#PoissonSolverMGRestrictionMethod"))
+aux2 = insFld(aux1, gFld("Subsystems", "vars/Hamiltonian.html#Hamiltonian::Subsystems"))
+insDoc(aux2, gLnk("R", "TnaddFactor", "vars/Hamiltonian.html#TnaddFactor"))
+insDoc(aux2, gLnk("R", "TnaddFunctional", "vars/Hamiltonian.html#TnaddFunctional"))
+insDoc(aux2, gLnk("R", "TnaddPolarized", "vars/Hamiltonian.html#TnaddPolarized"))
 aux2 = insFld(aux1, gFld("XC", "vars/Hamiltonian.html#Hamiltonian::XC"))
 insDoc(aux2, gLnk("R", "Interaction1D", "vars/Hamiltonian.html#Interaction1D"))
 insDoc(aux2, gLnk("R", "Interaction1DScreening", "vars/Hamiltonian.html#Interaction1DScreening"))
@@ -188,6 +213,8 @@ insDoc(aux2, gLnk("R", "LB94_threshold", "vars/Hamiltonian.html#LB94_threshold")
 insDoc(aux2, gLnk("R", "OEPLevel", "vars/Hamiltonian.html#OEPLevel"))
 insDoc(aux2, gLnk("R", "OEPMixing", "vars/Hamiltonian.html#OEPMixing"))
 insDoc(aux2, gLnk("R", "SICCorrection", "vars/Hamiltonian.html#SICCorrection"))
+insDoc(aux2, gLnk("R", "VDWCorrection", "vars/Hamiltonian.html#VDWCorrection"))
+insDoc(aux2, gLnk("R", "VDWSelfConsistent", "vars/Hamiltonian.html#VDWSelfConsistent"))
 insDoc(aux2, gLnk("R", "XCFunctional", "vars/Hamiltonian.html#XCFunctional"))
 insDoc(aux2, gLnk("R", "XCKernel", "vars/Hamiltonian.html#XCKernel"))
 insDoc(aux2, gLnk("R", "XCKernelLRCAlpha", "vars/Hamiltonian.html#XCKernelLRCAlpha"))
@@ -220,15 +247,18 @@ insDoc(aux2, gLnk("R", "KdotPCalculateEffectiveMasses", "vars/Linear_Response.ht
 insDoc(aux2, gLnk("R", "KdotPEta", "vars/Linear_Response.html#KdotPEta"))
 insDoc(aux2, gLnk("R", "KdotPOccupiedSolutionMethod", "vars/Linear_Response.html#KdotPOccupiedSolutionMethod"))
 insDoc(aux2, gLnk("R", "KdotPUseNonLocalPseudopotential", "vars/Linear_Response.html#KdotPUseNonLocalPseudopotential"))
+insDoc(aux2, gLnk("R", "KdotPVelMethod", "vars/Linear_Response.html#KdotPVelMethod"))
 aux2 = insFld(aux1, gFld("Polarizabilities", "vars/Linear_Response.html#Linear_Response::Polarizabilities"))
 insDoc(aux2, gLnk("R", "BornChargeSumRuleCorrection", "vars/Linear_Response.html#BornChargeSumRuleCorrection"))
 insDoc(aux2, gLnk("R", "EMCalcBornCharges", "vars/Linear_Response.html#EMCalcBornCharges"))
+insDoc(aux2, gLnk("R", "EMCalcMagnetooptics", "vars/Linear_Response.html#EMCalcMagnetooptics"))
 insDoc(aux2, gLnk("R", "EMCalcRotatoryResponse", "vars/Linear_Response.html#EMCalcRotatoryResponse"))
 insDoc(aux2, gLnk("R", "EMEta", "vars/Linear_Response.html#EMEta"))
 insDoc(aux2, gLnk("R", "EMForceNoKdotP", "vars/Linear_Response.html#EMForceNoKdotP"))
 insDoc(aux2, gLnk("R", "EMFreqs", "vars/Linear_Response.html#EMFreqs"))
 insDoc(aux2, gLnk("R", "EMFreqsSort", "vars/Linear_Response.html#EMFreqsSort"))
 insDoc(aux2, gLnk("R", "EMHyperpol", "vars/Linear_Response.html#EMHyperpol"))
+insDoc(aux2, gLnk("R", "EMMagnetoopticsNoHVar", "vars/Linear_Response.html#EMMagnetoopticsNoHVar"))
 insDoc(aux2, gLnk("R", "EMOccupiedResponse", "vars/Linear_Response.html#EMOccupiedResponse"))
 insDoc(aux2, gLnk("R", "EMPerturbationType", "vars/Linear_Response.html#EMPerturbationType"))
 insDoc(aux2, gLnk("R", "EMWavefunctionsFromScratch", "vars/Linear_Response.html#EMWavefunctionsFromScratch"))
@@ -283,7 +313,6 @@ insDoc(aux1, gLnk("R", "DoubleGridOrder", "vars/Mesh.html#DoubleGridOrder"))
 insDoc(aux1, gLnk("R", "MultiResolutionArea", "vars/Mesh.html#MultiResolutionArea"))
 insDoc(aux1, gLnk("R", "MultiResolutionInterpolationOrder", "vars/Mesh.html#MultiResolutionInterpolationOrder"))
 insDoc(aux1, gLnk("R", "MultigridLevels", "vars/Mesh.html#MultigridLevels"))
-insDoc(aux1, gLnk("R", "OpenBoundaries", "vars/Mesh.html#OpenBoundaries"))
 insDoc(aux1, gLnk("R", "Spacing", "vars/Mesh.html#Spacing"))
 insDoc(aux1, gLnk("R", "UseFineMesh", "vars/Mesh.html#UseFineMesh"))
 aux2 = insFld(aux1, gFld("Curvilinear", "vars/Mesh.html#Mesh::Curvilinear"))
@@ -326,12 +355,6 @@ insDoc(aux2, gLnk("R", "Lsize", "vars/Mesh.html#Lsize"))
 insDoc(aux2, gLnk("R", "Radius", "vars/Mesh.html#Radius"))
 insDoc(aux2, gLnk("R", "SymmetryBreakDir", "vars/Mesh.html#SymmetryBreakDir"))
 insDoc(aux2, gLnk("R", "Xlength", "vars/Mesh.html#Xlength"))
-aux1 = insFld(aux0, gFld("Open Boundaries", "vars/Open_Boundaries.html#Open_Boundaries"))
-insDoc(aux1, gLnk("R", "OpenBoundariesAdditionalTerms", "vars/Open_Boundaries.html#OpenBoundariesAdditionalTerms"))
-insDoc(aux1, gLnk("R", "OpenBoundariesMaxMemCoeffs", "vars/Open_Boundaries.html#OpenBoundariesMaxMemCoeffs"))
-insDoc(aux1, gLnk("R", "OpenBoundariesMemType", "vars/Open_Boundaries.html#OpenBoundariesMemType"))
-insDoc(aux1, gLnk("R", "OpenBoundariesQMRMaxIter", "vars/Open_Boundaries.html#OpenBoundariesQMRMaxIter"))
-insDoc(aux1, gLnk("R", "OpenBoundariesQMRTol", "vars/Open_Boundaries.html#OpenBoundariesQMRTol"))
 aux1 = insFld(aux0, gFld("Output", "vars/Output.html#Output"))
 insDoc(aux1, gLnk("R", "CurrentThroughPlane", "vars/Output.html#CurrentThroughPlane"))
 insDoc(aux1, gLnk("R", "DOSEnergyMax", "vars/Output.html#DOSEnergyMax"))
@@ -346,7 +369,7 @@ insDoc(aux1, gLnk("R", "Output", "vars/Output.html#Output"))
 insDoc(aux1, gLnk("R", "OutputBandsGnuplotMode", "vars/Output.html#OutputBandsGnuplotMode"))
 insDoc(aux1, gLnk("R", "OutputBandsGraceMode", "vars/Output.html#OutputBandsGraceMode"))
 insDoc(aux1, gLnk("R", "OutputDuringSCF", "vars/Output.html#OutputDuringSCF"))
-insDoc(aux1, gLnk("R", "OutputHow", "vars/Output.html#OutputHow"))
+insDoc(aux1, gLnk("R", "OutputFormat", "vars/Output.html#OutputFormat"))
 insDoc(aux1, gLnk("R", "OutputInterval", "vars/Output.html#OutputInterval"))
 insDoc(aux1, gLnk("R", "OutputIterDir", "vars/Output.html#OutputIterDir"))
 insDoc(aux1, gLnk("R", "OutputMEMultipoles", "vars/Output.html#OutputMEMultipoles"))
@@ -364,9 +387,13 @@ insDoc(aux2, gLnk("R", "BerkeleyGW_Vxc_diag_nmin", "vars/Output.html#BerkeleyGW_
 insDoc(aux2, gLnk("R", "BerkeleyGW_Vxc_offdiag_nmax", "vars/Output.html#BerkeleyGW_Vxc_offdiag_nmax"))
 insDoc(aux2, gLnk("R", "BerkeleyGW_Vxc_offdiag_nmin", "vars/Output.html#BerkeleyGW_Vxc_offdiag_nmin"))
 insDoc(aux2, gLnk("R", "BerkeleyGW_WFN_filename", "vars/Output.html#BerkeleyGW_WFN_filename"))
+aux2 = insFld(aux1, gFld("Subsystems", "vars/Output.html#Output::Subsystems"))
+insDoc(aux2, gLnk("R", "FrozenDir", "vars/Output.html#FrozenDir"))
+insDoc(aux2, gLnk("R", "FrozenStates", "vars/Output.html#FrozenStates"))
 aux1 = insFld(aux0, gFld("SCF", "vars/SCF.html#SCF"))
 insDoc(aux1, gLnk("R", "SCFCalculateDipole", "vars/SCF.html#SCFCalculateDipole"))
 insDoc(aux1, gLnk("R", "SCFCalculateForces", "vars/SCF.html#SCFCalculateForces"))
+insDoc(aux1, gLnk("R", "SCFCalculatePartialCharges", "vars/SCF.html#SCFCalculatePartialCharges"))
 insDoc(aux1, gLnk("R", "SCFinLCAO", "vars/SCF.html#SCFinLCAO"))
 aux2 = insFld(aux1, gFld("Convergence", "vars/SCF.html#SCF::Convergence"))
 insDoc(aux2, gLnk("R", "ConvAbsDens", "vars/SCF.html#ConvAbsDens"))
@@ -412,10 +439,9 @@ aux2 = insFld(aux1, gFld("Mixing", "vars/SCF.html#SCF::Mixing"))
 insDoc(aux2, gLnk("R", "MixField", "vars/SCF.html#MixField"))
 insDoc(aux2, gLnk("R", "MixNumberSteps", "vars/SCF.html#MixNumberSteps"))
 insDoc(aux2, gLnk("R", "Mixing", "vars/SCF.html#Mixing"))
-insDoc(aux2, gLnk("R", "TypeOfMixing", "vars/SCF.html#TypeOfMixing"))
+insDoc(aux2, gLnk("R", "MixingScheme", "vars/SCF.html#MixingScheme"))
 aux2 = insFld(aux1, gFld("RDMFT", "vars/SCF.html#SCF::RDMFT"))
 insDoc(aux2, gLnk("R", "RDMConvEner", "vars/SCF.html#RDMConvEner"))
-insDoc(aux2, gLnk("R", "RDMMaxIter", "vars/SCF.html#RDMMaxIter"))
 insDoc(aux2, gLnk("R", "RDMTolerance", "vars/SCF.html#RDMTolerance"))
 aux1 = insFld(aux0, gFld("States", "vars/States.html#States"))
 insDoc(aux1, gLnk("R", "DegeneracyThreshold", "vars/States.html#DegeneracyThreshold"))
@@ -453,9 +479,13 @@ insDoc(aux2, gLnk("R", "XSFCoordinatesAnimStep", "vars/System.html#XSFCoordinate
 insDoc(aux2, gLnk("R", "XYZCoordinates", "vars/System.html#XYZCoordinates"))
 aux2 = insFld(aux1, gFld("Species", "vars/System.html#System::Species"))
 insDoc(aux2, gLnk("R", "IonicInteraction", "vars/System.html#IonicInteraction"))
+insDoc(aux2, gLnk("R", "PseudopotentialSet", "vars/System.html#PseudopotentialSet"))
 insDoc(aux2, gLnk("R", "Species", "vars/System.html#Species"))
 insDoc(aux2, gLnk("R", "SpeciesProjectorSphereThreshold", "vars/System.html#SpeciesProjectorSphereThreshold"))
 insDoc(aux2, gLnk("R", "SpeciesTimeDependent", "vars/System.html#SpeciesTimeDependent"))
+aux2 = insFld(aux1, gFld("Subsystems", "vars/System.html#System::Subsystems"))
+insDoc(aux2, gLnk("R", "SubSystemCoordinates", "vars/System.html#SubSystemCoordinates"))
+insDoc(aux2, gLnk("R", "SubSystems", "vars/System.html#SubSystems"))
 aux2 = insFld(aux1, gFld("Velocities", "vars/System.html#System::Velocities"))
 insDoc(aux2, gLnk("R", "PDBVelocities", "vars/System.html#PDBVelocities"))
 insDoc(aux2, gLnk("R", "RandomVelocityTemp", "vars/System.html#RandomVelocityTemp"))
@@ -467,29 +497,48 @@ insDoc(aux1, gLnk("R", "TDExternalFields", "vars/Time-Dependent.html#TDExternalF
 insDoc(aux1, gLnk("R", "TDFreezeHXC", "vars/Time-Dependent.html#TDFreezeHXC"))
 insDoc(aux1, gLnk("R", "TDFreezeOrbitals", "vars/Time-Dependent.html#TDFreezeOrbitals"))
 insDoc(aux1, gLnk("R", "TDFunctions", "vars/Time-Dependent.html#TDFunctions"))
+insDoc(aux1, gLnk("R", "TDGlobalForce", "vars/Time-Dependent.html#TDGlobalForce"))
 aux2 = insFld(aux1, gFld("Absorbing Boundaries", "vars/Time-Dependent.html#Time-Dependent::Absorbing_Boundaries"))
+insDoc(aux2, gLnk("R", "ABCapHeight", "vars/Time-Dependent.html#ABCapHeight"))
 insDoc(aux2, gLnk("R", "ABHeight", "vars/Time-Dependent.html#ABHeight"))
+insDoc(aux2, gLnk("R", "ABShape", "vars/Time-Dependent.html#ABShape"))
+insDoc(aux2, gLnk("R", "ABType", "vars/Time-Dependent.html#ABType"))
 insDoc(aux2, gLnk("R", "ABWidth", "vars/Time-Dependent.html#ABWidth"))
 insDoc(aux2, gLnk("R", "AbsorbingBoundaries", "vars/Time-Dependent.html#AbsorbingBoundaries"))
-aux2 = insFld(aux1, gFld("Open Boundaries", "vars/Time-Dependent.html#Time-Dependent::Open_Boundaries"))
-insDoc(aux2, gLnk("R", "MemoryMaxIter", "vars/Time-Dependent.html#MemoryMaxIter"))
-insDoc(aux2, gLnk("R", "MemoryTol", "vars/Time-Dependent.html#MemoryTol"))
 aux2 = insFld(aux1, gFld("PhotoElectronSpectrum", "vars/Time-Dependent.html#Time-Dependent::PhotoElectronSpectrum"))
 insDoc(aux2, gLnk("R", "PESMask2PEnlargeFactor", "vars/Time-Dependent.html#PESMask2PEnlargeFactor"))
 insDoc(aux2, gLnk("R", "PESMaskEnlargeFactor", "vars/Time-Dependent.html#PESMaskEnlargeFactor"))
 insDoc(aux2, gLnk("R", "PESMaskFilterCutOff", "vars/Time-Dependent.html#PESMaskFilterCutOff"))
 insDoc(aux2, gLnk("R", "PESMaskIncludePsiA", "vars/Time-Dependent.html#PESMaskIncludePsiA"))
 insDoc(aux2, gLnk("R", "PESMaskMode", "vars/Time-Dependent.html#PESMaskMode"))
-insDoc(aux2, gLnk("R", "PESMaskOutputInterpolate", "vars/Time-Dependent.html#PESMaskOutputInterpolate"))
 insDoc(aux2, gLnk("R", "PESMaskPlaneWaveProjection", "vars/Time-Dependent.html#PESMaskPlaneWaveProjection"))
-insDoc(aux2, gLnk("R", "PESMaskPropagator", "vars/Time-Dependent.html#PESMaskPropagator"))
 insDoc(aux2, gLnk("R", "PESMaskShape", "vars/Time-Dependent.html#PESMaskShape"))
 insDoc(aux2, gLnk("R", "PESMaskSize", "vars/Time-Dependent.html#PESMaskSize"))
 insDoc(aux2, gLnk("R", "PESMaskSpectEnergyMax", "vars/Time-Dependent.html#PESMaskSpectEnergyMax"))
 insDoc(aux2, gLnk("R", "PESMaskSpectEnergyStep", "vars/Time-Dependent.html#PESMaskSpectEnergyStep"))
 insDoc(aux2, gLnk("R", "PESMaskStartTime", "vars/Time-Dependent.html#PESMaskStartTime"))
+insDoc(aux2, gLnk("R", "PES_Flux_DeltaK", "vars/Time-Dependent.html#PES_Flux_DeltaK"))
+insDoc(aux2, gLnk("R", "PES_Flux_Kmax", "vars/Time-Dependent.html#PES_Flux_Kmax"))
+insDoc(aux2, gLnk("R", "PES_Flux_Lmax", "vars/Time-Dependent.html#PES_Flux_Lmax"))
+insDoc(aux2, gLnk("R", "PES_Flux_Lsize", "vars/Time-Dependent.html#PES_Flux_Lsize"))
+insDoc(aux2, gLnk("R", "PES_Flux_Offset", "vars/Time-Dependent.html#PES_Flux_Offset"))
+insDoc(aux2, gLnk("R", "PES_Flux_Radius", "vars/Time-Dependent.html#PES_Flux_Radius"))
+insDoc(aux2, gLnk("R", "PES_Flux_Shape", "vars/Time-Dependent.html#PES_Flux_Shape"))
+insDoc(aux2, gLnk("R", "PES_Flux_StepsPhiK", "vars/Time-Dependent.html#PES_Flux_StepsPhiK"))
+insDoc(aux2, gLnk("R", "PES_Flux_StepsPhiR", "vars/Time-Dependent.html#PES_Flux_StepsPhiR"))
+insDoc(aux2, gLnk("R", "PES_Flux_StepsThetaK", "vars/Time-Dependent.html#PES_Flux_StepsThetaK"))
+insDoc(aux2, gLnk("R", "PES_Flux_StepsThetaR", "vars/Time-Dependent.html#PES_Flux_StepsThetaR"))
+insDoc(aux2, gLnk("R", "PES_Flux_TDSteps", "vars/Time-Dependent.html#PES_Flux_TDSteps"))
+insDoc(aux2, gLnk("R", "PES_Flux_TDStepsInterval", "vars/Time-Dependent.html#PES_Flux_TDStepsInterval"))
+insDoc(aux2, gLnk("R", "PES_Flux_UseMemory", "vars/Time-Dependent.html#PES_Flux_UseMemory"))
+insDoc(aux2, gLnk("R", "PES_spm_DeltaOmega", "vars/Time-Dependent.html#PES_spm_DeltaOmega"))
+insDoc(aux2, gLnk("R", "PES_spm_OmegaMax", "vars/Time-Dependent.html#PES_spm_OmegaMax"))
+insDoc(aux2, gLnk("R", "PES_spm_Radius", "vars/Time-Dependent.html#PES_spm_Radius"))
+insDoc(aux2, gLnk("R", "PES_spm_StepsPhiR", "vars/Time-Dependent.html#PES_spm_StepsPhiR"))
+insDoc(aux2, gLnk("R", "PES_spm_StepsThetaR", "vars/Time-Dependent.html#PES_spm_StepsThetaR"))
+insDoc(aux2, gLnk("R", "PES_spm_points", "vars/Time-Dependent.html#PES_spm_points"))
+insDoc(aux2, gLnk("R", "PES_spm_recipe", "vars/Time-Dependent.html#PES_spm_recipe"))
 insDoc(aux2, gLnk("R", "PhotoElectronSpectrum", "vars/Time-Dependent.html#PhotoElectronSpectrum"))
-insDoc(aux2, gLnk("R", "PhotoElectronSpectrumPoints", "vars/Time-Dependent.html#PhotoElectronSpectrumPoints"))
 aux2 = insFld(aux1, gFld("Propagation", "vars/Time-Dependent.html#Time-Dependent::Propagation"))
 insDoc(aux2, gLnk("R", "IonsConstantVelocity", "vars/Time-Dependent.html#IonsConstantVelocity"))
 insDoc(aux2, gLnk("R", "MoveIons", "vars/Time-Dependent.html#MoveIons"))
@@ -500,7 +549,8 @@ insDoc(aux2, gLnk("R", "TDExpOrder", "vars/Time-Dependent.html#TDExpOrder"))
 insDoc(aux2, gLnk("R", "TDExponentialMethod", "vars/Time-Dependent.html#TDExponentialMethod"))
 insDoc(aux2, gLnk("R", "TDIonicTimeScale", "vars/Time-Dependent.html#TDIonicTimeScale"))
 insDoc(aux2, gLnk("R", "TDLanczosTol", "vars/Time-Dependent.html#TDLanczosTol"))
-insDoc(aux2, gLnk("R", "TDMaximumIter", "vars/Time-Dependent.html#TDMaximumIter"))
+insDoc(aux2, gLnk("R", "TDMaxSteps", "vars/Time-Dependent.html#TDMaxSteps"))
+insDoc(aux2, gLnk("R", "TDPropagationTime", "vars/Time-Dependent.html#TDPropagationTime"))
 insDoc(aux2, gLnk("R", "TDPropagator", "vars/Time-Dependent.html#TDPropagator"))
 insDoc(aux2, gLnk("R", "TDSCFThreshold", "vars/Time-Dependent.html#TDSCFThreshold"))
 insDoc(aux2, gLnk("R", "TDStepsWithSelfConsistency", "vars/Time-Dependent.html#TDStepsWithSelfConsistency"))
@@ -525,10 +575,6 @@ insDoc(aux2, gLnk("R", "TDExcitedStatesToProject", "vars/Time-Dependent.html#TDE
 insDoc(aux2, gLnk("R", "TDMultipoleLmax", "vars/Time-Dependent.html#TDMultipoleLmax"))
 insDoc(aux2, gLnk("R", "TDOutput", "vars/Time-Dependent.html#TDOutput"))
 insDoc(aux2, gLnk("R", "TDProjStateStart", "vars/Time-Dependent.html#TDProjStateStart"))
-aux2 = insFld(aux1, gFld("TDPSF", "vars/Time-Dependent.html#Time-Dependent::TDPSF"))
-insDoc(aux2, gLnk("R", "TDPSFDelta", "vars/Time-Dependent.html#TDPSFDelta"))
-insDoc(aux2, gLnk("R", "TDPSFKmin", "vars/Time-Dependent.html#TDPSFKmin"))
-insDoc(aux2, gLnk("R", "TDPSFSigma", "vars/Time-Dependent.html#TDPSFSigma"))
 aux1 = insFld(aux0, gFld("Utilities", "vars/Utilities.html#Utilities::oct-casida_spectrum"))
 aux2 = insFld(aux1, gFld("oct-casida_spectrum", "vars/Utilities.html#Utilities::oct-casida_spectrum"))
 insDoc(aux2, gLnk("R", "CasidaSpectrumBroadening", "vars/Utilities.html#CasidaSpectrumBroadening"))
@@ -539,49 +585,66 @@ insDoc(aux2, gLnk("R", "CasidaSpectrumRotationMatrix", "vars/Utilities.html#Casi
 aux2 = insFld(aux1, gFld("oct-center-geom", "vars/Utilities.html#Utilities::oct-center-geom"))
 insDoc(aux2, gLnk("R", "AxisType", "vars/Utilities.html#AxisType"))
 insDoc(aux2, gLnk("R", "MainAxis", "vars/Utilities.html#MainAxis"))
+aux2 = insFld(aux1, gFld("oct-conductivity_spectrum", "vars/Utilities.html#Utilities::oct-conductivity_spectrum"))
+insDoc(aux2, gLnk("R", "ConductivitySpectrumTimeStepFactor", "vars/Utilities.html#ConductivitySpectrumTimeStepFactor"))
 aux2 = insFld(aux1, gFld("oct-convert", "vars/Utilities.html#Utilities::oct-convert"))
 insDoc(aux2, gLnk("R", "ConvertEnd", "vars/Utilities.html#ConvertEnd"))
 insDoc(aux2, gLnk("R", "ConvertEnergyMax", "vars/Utilities.html#ConvertEnergyMax"))
 insDoc(aux2, gLnk("R", "ConvertEnergyMin", "vars/Utilities.html#ConvertEnergyMin"))
+insDoc(aux2, gLnk("R", "ConvertEnergyStep", "vars/Utilities.html#ConvertEnergyStep"))
+insDoc(aux2, gLnk("R", "ConvertFTMethod", "vars/Utilities.html#ConvertFTMethod"))
 insDoc(aux2, gLnk("R", "ConvertFilename", "vars/Utilities.html#ConvertFilename"))
 insDoc(aux2, gLnk("R", "ConvertFolder", "vars/Utilities.html#ConvertFolder"))
+insDoc(aux2, gLnk("R", "ConvertHow", "vars/Utilities.html#ConvertHow"))
 insDoc(aux2, gLnk("R", "ConvertIterateFolder", "vars/Utilities.html#ConvertIterateFolder"))
+insDoc(aux2, gLnk("R", "ConvertOutputFilename", "vars/Utilities.html#ConvertOutputFilename"))
+insDoc(aux2, gLnk("R", "ConvertOutputFolder", "vars/Utilities.html#ConvertOutputFolder"))
 insDoc(aux2, gLnk("R", "ConvertReadSize", "vars/Utilities.html#ConvertReadSize"))
 insDoc(aux2, gLnk("R", "ConvertStart", "vars/Utilities.html#ConvertStart"))
 insDoc(aux2, gLnk("R", "ConvertStep", "vars/Utilities.html#ConvertStep"))
 insDoc(aux2, gLnk("R", "ConvertSubtract", "vars/Utilities.html#ConvertSubtract"))
 insDoc(aux2, gLnk("R", "ConvertSubtractFilename", "vars/Utilities.html#ConvertSubtractFilename"))
 insDoc(aux2, gLnk("R", "ConvertSubtractFolder", "vars/Utilities.html#ConvertSubtractFolder"))
-insDoc(aux2, gLnk("R", "ConvertTransform", "vars/Utilities.html#ConvertTransform"))
-aux2 = insFld(aux1, gFld("oct-liquid", "vars/Utilities.html#Utilities::oct-liquid"))
-insDoc(aux2, gLnk("R", "LiquidDensity", "vars/Utilities.html#LiquidDensity"))
-insDoc(aux2, gLnk("R", "LiquidMoleculeScale", "vars/Utilities.html#LiquidMoleculeScale"))
-insDoc(aux2, gLnk("R", "LiquidNumberOfMolecules", "vars/Utilities.html#LiquidNumberOfMolecules"))
 aux2 = insFld(aux1, gFld("oct-local_multipoles", "vars/Utilities.html#Utilities::oct-local_multipoles"))
+insDoc(aux2, gLnk("R", "ConvertScalarOperation", "vars/Utilities.html#ConvertScalarOperation"))
 insDoc(aux2, gLnk("R", "LDBaderThreshold", "vars/Utilities.html#LDBaderThreshold"))
+insDoc(aux2, gLnk("R", "LDEnd", "vars/Utilities.html#LDEnd"))
 insDoc(aux2, gLnk("R", "LDExtraWrite", "vars/Utilities.html#LDExtraWrite"))
 insDoc(aux2, gLnk("R", "LDFilename", "vars/Utilities.html#LDFilename"))
 insDoc(aux2, gLnk("R", "LDFolder", "vars/Utilities.html#LDFolder"))
+insDoc(aux2, gLnk("R", "LDIterateFolder", "vars/Utilities.html#LDIterateFolder"))
 insDoc(aux2, gLnk("R", "LDMultipoleLmax", "vars/Utilities.html#LDMultipoleLmax"))
 insDoc(aux2, gLnk("R", "LDOutput", "vars/Utilities.html#LDOutput"))
-insDoc(aux2, gLnk("R", "LDOutputHow", "vars/Utilities.html#LDOutputHow"))
+insDoc(aux2, gLnk("R", "LDOutputFormat", "vars/Utilities.html#LDOutputFormat"))
 insDoc(aux2, gLnk("R", "LDOverWrite", "vars/Utilities.html#LDOverWrite"))
 insDoc(aux2, gLnk("R", "LDRadiiFile", "vars/Utilities.html#LDRadiiFile"))
+insDoc(aux2, gLnk("R", "LDRestart", "vars/Utilities.html#LDRestart"))
+insDoc(aux2, gLnk("R", "LDRestartFolder", "vars/Utilities.html#LDRestartFolder"))
+insDoc(aux2, gLnk("R", "LDStart", "vars/Utilities.html#LDStart"))
+insDoc(aux2, gLnk("R", "LDStep", "vars/Utilities.html#LDStep"))
 insDoc(aux2, gLnk("R", "LDUpdate", "vars/Utilities.html#LDUpdate"))
-insDoc(aux2, gLnk("R", "LocalDomain", "vars/Utilities.html#LocalDomain"))
+insDoc(aux2, gLnk("R", "LDUseAtomicRadii", "vars/Utilities.html#LDUseAtomicRadii"))
+insDoc(aux2, gLnk("R", "LocalDomains", "vars/Utilities.html#LocalDomains"))
+aux2 = insFld(aux1, gFld("oct-photoelectron_spectrum", "vars/Utilities.html#Utilities::oct-photoelectron_spectrum"))
+insDoc(aux2, gLnk("R", "PhotoelectronSpectrumOutput", "vars/Utilities.html#PhotoelectronSpectrumOutput"))
+insDoc(aux2, gLnk("R", "PhotoelectronSpectrumResolveStates", "vars/Utilities.html#PhotoelectronSpectrumResolveStates"))
 aux2 = insFld(aux1, gFld("oct-propagation_spectrum", "vars/Utilities.html#Utilities::oct-propagation_spectrum"))
 insDoc(aux2, gLnk("R", "PropagationSpectrumDampFactor", "vars/Utilities.html#PropagationSpectrumDampFactor"))
 insDoc(aux2, gLnk("R", "PropagationSpectrumDampMode", "vars/Utilities.html#PropagationSpectrumDampMode"))
 insDoc(aux2, gLnk("R", "PropagationSpectrumEndTime", "vars/Utilities.html#PropagationSpectrumEndTime"))
 insDoc(aux2, gLnk("R", "PropagationSpectrumEnergyStep", "vars/Utilities.html#PropagationSpectrumEnergyStep"))
 insDoc(aux2, gLnk("R", "PropagationSpectrumMaxEnergy", "vars/Utilities.html#PropagationSpectrumMaxEnergy"))
+insDoc(aux2, gLnk("R", "PropagationSpectrumSigmaDiagonalization", "vars/Utilities.html#PropagationSpectrumSigmaDiagonalization"))
 insDoc(aux2, gLnk("R", "PropagationSpectrumStartTime", "vars/Utilities.html#PropagationSpectrumStartTime"))
 insDoc(aux2, gLnk("R", "PropagationSpectrumTransform", "vars/Utilities.html#PropagationSpectrumTransform"))
 insDoc(aux2, gLnk("R", "PropagationSpectrumType", "vars/Utilities.html#PropagationSpectrumType"))
 insDoc(aux2, gLnk("R", "SpectrumMethod", "vars/Utilities.html#SpectrumMethod"))
 insDoc(aux2, gLnk("R", "SpectrumSignalNoise", "vars/Utilities.html#SpectrumSignalNoise"))
 aux2 = insFld(aux1, gFld("oct-test", "vars/Utilities.html#Utilities::oct-test"))
+insDoc(aux2, gLnk("R", "TestMaxBlockSize", "vars/Utilities.html#TestMaxBlockSize"))
+insDoc(aux2, gLnk("R", "TestMinBlockSize", "vars/Utilities.html#TestMinBlockSize"))
 insDoc(aux2, gLnk("R", "TestMode", "vars/Utilities.html#TestMode"))
+insDoc(aux2, gLnk("R", "TestRepetitions", "vars/Utilities.html#TestRepetitions"))
 insDoc(aux2, gLnk("R", "TestType", "vars/Utilities.html#TestType"))
 aux2 = insFld(aux1, gFld("oct-vibrational_spectrum", "vars/Utilities.html#Utilities::oct-vibrational_spectrum"))
 insDoc(aux2, gLnk("R", "VibrationalSpectrumTime", "vars/Utilities.html#VibrationalSpectrumTime"))
