@@ -37,12 +37,26 @@ module bpdn_m
       implicit none
 
       integer, intent(in)    :: nn
-      real(8), intent(inout) :: xx !(1:nn)
-      real(8), intent(in)    :: cc !(1:nn)
+      real(8), intent(inout) :: xx !< (1:nn)
+      real(8), intent(in)    :: cc !< (1:nn)
       real(8), intent(in)    :: tau
     end subroutine spgl1_projector
   end interface
 
+  interface
+     subroutine expmm(nx, ny, x, y, dx, dy, component)
+       implicit none
+       
+       integer, intent(in)  :: nx
+       integer, intent(in)  :: ny
+       real(8), intent(in)  :: x !< (1:nx)
+       real(8), intent(out) :: y !< (1:ny)
+       real(8), intent(in)  :: dx
+       real(8), intent(in)  :: dy
+       integer, intent(in)  :: component
+     end subroutine expmm
+  end interface
+
   integer, parameter ::        &
     EXIT_LINE_ERROR    =-2,    &
     EXIT_ITERATIONS    =-1,    &
@@ -65,14 +79,14 @@ module bpdn_m
       integer,   intent(in)    :: m
       integer,   intent(in)    :: n
       real(8),   intent(in)    :: alpha
-      real(8),   intent(in)    :: a !(1:lda, :)
+      real(8),   intent(in)    :: a !< (1:lda, :)
       integer,   intent(in)    :: lda
-      real(8),   intent(in)    :: x !(:)
+      real(8),   intent(in)    :: x !< (:)
       integer,   intent(in)    :: incx
       real(8),   intent(in)    :: beta
-      real(8),   intent(in)    :: y !(:)
+      real(8),   intent(inout) :: y !< (:)
       integer,   intent(in)    :: incy
-    end SUBROUTINE DGEMV
+    end subroutine dgemv
   end interface
 
   real(8), parameter :: opttol = 1.0e-6_8
@@ -86,7 +100,7 @@ module bpdn_m
     integer          :: type
     integer          :: nn
     integer          :: mm
-    real(8), pointer :: matrix(:, :) !(1:nn, 1:mm)
+    real(8), pointer :: matrix(:, :) !< (1:nn, 1:mm)
     real(8)          :: dnn
     real(8)          :: dmm
   end type bpdn_matrix
@@ -131,11 +145,12 @@ contains
   end subroutine bpdn_matrix_set_delta
 
   subroutine bpdn(nn, mm, aa, bb, sigma, xx, ierr, activesetit)
+    integer,           intent(out)   :: nn, mm
     type(bpdn_matrix), intent(in)    :: aa
-    real(8),           intent(in)    :: bb(:)    !(1:nn)
+    real(8),           intent(in)    :: bb(:)    !< (1:nn)
     real(8),           intent(in)    :: sigma
-    real(8),           intent(out)   :: xx(:)    !(1:mm)
-    integer, optional, intent(out)   :: ierr     ! < 0 : some error occurred. >= 0 : solution found
+    real(8),           intent(out)   :: xx(:)    !< (1:mm)
+    integer, optional, intent(out)   :: ierr     !<  < 0 : some error occurred. >= 0 : solution found
     integer, optional, intent(in)    :: activesetit
 
     integer, parameter :: nprevvals = 3
@@ -151,7 +166,6 @@ contains
     integer :: nnziter, iter, maxits, lserr, status, maxlineerrors, nnzdiff, nnzg, nnzx
     logical :: done, testrelchange1, testrelchange2, testupdatetau, singletau
     logical, allocatable :: nnzidx(:)
-    integer :: nn, mm
 
     nn = aa%nn
     mm = aa%mm
@@ -193,7 +207,7 @@ contains
     call calc_grad(aa, res, grad)
     ff = dotp(nn, res, res)/2.0_8
 
-    ! Required for nonmonotone strategy.
+    ! Required for non-monotonic strategy.
     lastffv(1:nprevvals) = ff
     ffbest               = ff
     xxbest(1:mm)         = xx(1:mm)
@@ -397,15 +411,15 @@ contains
   !----------------------------------------------------------
 
   subroutine spg_line_curvy(aa, bb, xx, gg, fmax, stepmax, tau, xxnew, resnew, fnew, ierr)
-    type(bpdn_matrix), intent(in) :: aa
-    real(8),           intent(in)    :: bb(:)    !(1:nn)
-    real(8),           intent(in)    :: xx(:)    !(1:mm)
-    real(8),           intent(in)    :: gg(:)    !(1:mm)
+    type(bpdn_matrix), intent(in)    :: aa
+    real(8),           intent(in)    :: bb(:)    !< (1:nn)
+    real(8),           intent(in)    :: xx(:)    !< (1:mm)
+    real(8),           intent(in)    :: gg(:)    !< (1:mm)
     real(8),           intent(in)    :: fmax
     real(8),           intent(in)    :: stepmax
     real(8),           intent(in)    :: tau
-    real(8),           intent(out)   :: xxnew(:)  !(1:mm)
-    real(8),           intent(out)   :: resnew(:) !(1:nn)
+    real(8),           intent(out)   :: xxnew(:)  !< (1:mm)
+    real(8),           intent(out)   :: resnew(:) !< (1:nn)
     real(8),           intent(out)   :: fnew
     integer,           intent(out)   :: ierr
 
@@ -439,7 +453,7 @@ contains
       gts = scale*dotp(mm, gg, ss)
 
       if(gts >= 0) then
-        ierr = EXIT_NODESCENT;
+        ierr = EXIT_NODESCENT
         exit
       end if
 
@@ -478,7 +492,7 @@ contains
 
   ! -----------------------------------------
 
-  ! Find the current active set.
+  !> Find the current active set.
   subroutine active_vars(mm, xx, gg, nnzidx, nnzx, nnzg, nnzdiff)
     integer, intent(in)    :: mm
     real(8), intent(in)    :: xx(:)
@@ -565,11 +579,11 @@ contains
   
   subroutine residual(aa, bb, xx, res)
     type(bpdn_matrix), intent(in)    :: aa
-    real(8),           intent(in)    :: bb(:)    !(1:aa%nn)
-    real(8),           intent(in)    :: xx(:)    !(1:aa%mm)
-    real(8),           intent(out)   :: res(:)   !(1:nn)
+    real(8),           intent(in)    :: bb(:)    !< (1:aa%nn)
+    real(8),           intent(in)    :: xx(:)    !< (1:aa%mm)
+    real(8),           intent(out)   :: res(:)   !< (1:nn)
 
-    integer :: inn, comp
+    integer :: inn
 
     select case(aa%type)
     case(EXPLICIT_MATRIX)
@@ -579,9 +593,6 @@ contains
 
     case(SIN_MATRIX, COS_MATRIX)
 
-      comp = 0
-      if(aa%type == SIN_MATRIX) comp = 1
-
       call expmm(aa%mm, aa%nn, xx(1), res(1), aa%dmm, aa%dnn,  1)
         
       do inn = 1, aa%nn
@@ -596,8 +607,8 @@ contains
 
   subroutine calc_grad(aa, res, grad)
     type(bpdn_matrix), intent(in)    :: aa
-    real(8),           intent(in)    :: res(:)   !(1:aa%nn)
-    real(8),           intent(out)   :: grad(:)  !(1:aa%mm)
+    real(8),           intent(in)    :: res(:)   !< (1:aa%nn)
+    real(8),           intent(out)   :: grad(:)  !< (1:aa%mm)
 
     integer :: comp
 
