@@ -16,7 +16,7 @@
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.
 
- $Id: liboct_parser.h 12527 2014-10-03 18:44:13Z dstrubbe $
+ $Id: liboct_parser.h 14180 2015-06-02 02:01:12Z dstrubbe $
 */
 
 #ifndef _LIB_OCT_H
@@ -24,15 +24,15 @@
 
 #include <gsl/gsl_complex.h>
 
-int         parse_init   (char *file_out, int *mpiv_node);
-int         parse_input  (char *file_in);
+int         parse_init   (const char *file_out, const int *mpiv_node);
+int         parse_input  (const char *file_in);
 void        parse_end    (void);
 
-int         parse_isdef  (char *name);
-int         parse_int    (char *name, int def);
-double      parse_double (char *name, double def);
-gsl_complex parse_complex(char *name, gsl_complex def);
-char       *parse_string (char *name, char *def);
+int         parse_isdef  (const char *name);
+int         parse_int    (const char *name, int def);
+double      parse_double (const char *name, double def);
+gsl_complex parse_complex(const char *name, gsl_complex def);
+char       *parse_string (const char *name, char *def);
 
 /* Now comes stuff for the blocks */
 typedef struct sym_block_line{
@@ -43,16 +43,17 @@ typedef struct sym_block_line{
 typedef struct sym_block{
   int n;
   sym_block_line *lines;
+  char* name;
 } sym_block;
 
-int parse_block        (char *name, sym_block **blk);
+int parse_block        (const char *name, sym_block **blk);
 int parse_block_end    (sym_block **blk);
-int parse_block_n      (sym_block *blk);
-int parse_block_cols   (sym_block *blk, int l);
-int parse_block_int    (sym_block *blk, int l, int col, int *r);
-int parse_block_double (sym_block *blk, int l, int col, double *r);
-int parse_block_complex(sym_block *blk, int l, int col, gsl_complex *r);
-int parse_block_string (sym_block *blk, int l, int col, char **r);
+int parse_block_n      (const sym_block *blk);
+int parse_block_cols   (const sym_block *blk, int l);
+int parse_block_int    (const sym_block *blk, int l, int col, int *r);
+int parse_block_double (const sym_block *blk, int l, int col, double *r);
+int parse_block_complex(const sym_block *blk, int l, int col, gsl_complex *r);
+int parse_block_string (const sym_block *blk, int l, int col, char **r);
 
 /* from parse_exp.c */
 enum pr_type {PR_NONE,PR_CMPLX, PR_STR};
@@ -68,8 +69,8 @@ void parse_result_free(parse_result *t);
 
 int parse_exp(char *exp, parse_result *t);
 
-void parse_putsym_int(char *s, int i);
-void parse_putsym_double(char *s, double d);
-void parse_putsym_complex(char *s, gsl_complex c);
+void parse_putsym_int(const char *s, int i);
+void parse_putsym_double(const char *s, double d);
+void parse_putsym_complex(const char *s, gsl_complex c);
 
 #endif
