@@ -16,7 +16,7 @@
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.
 
- $Id: parse.c 12528 2014-10-03 19:07:03Z dstrubbe $
+ $Id: parse.c 14270 2015-06-12 22:18:11Z dstrubbe $
 */
 
 #include <stdio.h>
@@ -37,7 +37,7 @@ static int  disable_write;
 
 #define ROUND(x) ((x)<0 ? (int)(x-0.5) : (int)(x+0.5)) 
 
-static char *str_trim(char *in)
+void str_trim(char *in)
 {
   char *c, *s = in;
 
@@ -45,8 +45,6 @@ static char *str_trim(char *in)
   for(; *c != '\0'; *s++=*c++);
   for(s--; s>=in && isspace(*s); s--);
   *(s+1) = '\0';
-
-  return in;
 }
 
 static int parse_get_line(FILE *f, char **s, int *length)
@@ -72,7 +70,7 @@ static int parse_get_line(FILE *f, char **s, int *length)
   return c;
 }
 
-int parse_init(char *file_out, int *mpiv_node)
+int parse_init(const char *file_out, const int *mpiv_node)
 {
   sym_init_table();
 
@@ -94,7 +92,7 @@ int parse_init(char *file_out, int *mpiv_node)
   return 0;
 }
 
-int parse_input(char *file_in)
+int parse_input(const char *file_in)
 {
   FILE *f;
   char *s;
@@ -118,7 +116,7 @@ int parse_input(char *file_in)
 	*s = ' ';
 	str_trim(s);
 	if(getsym(s) != NULL){ /* error */
-	  fprintf(stderr, "%s \"%s\" %s", "Block", s, "already defined");
+	  fprintf(stderr, "Parser warning: %s \"%s\" %s.\n", "Block", s, "already defined");
 	  do{ /* skip block */
 	    c = parse_get_line(f, &s, &length);
 	  }while(c != EOF && *s != '%');
@@ -203,7 +201,7 @@ void parse_end()
   }
 }
 
-int parse_isdef(char *name)
+int parse_isdef(const char *name)
 {
   if(getsym(name) == NULL)
     return 0;
@@ -213,13 +211,13 @@ int parse_isdef(char *name)
 
 static void check_is_numerical(const char * name, const symrec * ptr){
   if( ptr->type != S_CMPLX){
-    fprintf(stderr, "Input error: expecting a numerical value for variable '%s' and found a string.\n", name);
+    fprintf(stderr, "Parser error: expecting a numerical value for variable '%s' and found a string.\n", name);
     exit(1);
   }
 }
 
 
-int parse_int(char *name, int def)
+int parse_int(const char *name, int def)
 {
   symrec *ptr;
   int ret;
@@ -231,6 +229,14 @@ int parse_int(char *name, int def)
     if(!disable_write) {
       fprintf(fout, "%s = %d\n", name, ret);
     }
+    if(fabs(GSL_IMAG(ptr->value.c)) > 1e-10) {
+       fprintf(stderr, "Parser error: complex value passed for integer variable '%s'.\n", name);
+       exit(1);
+    }
+    if(fabs(ret - GSL_REAL(ptr->value.c)) > 1e-10) {
+       fprintf(stderr, "Parser error: non-integer value passed for integer variable '%s'.\n", name);
+       exit(1);
+    }
   }else{
     ret = def;
     if(!disable_write) {
@@ -240,7 +246,7 @@ int parse_int(char *name, int def)
   return ret;
 }
 
-double parse_double(char *name, double def)
+double parse_double(const char *name, double def)
 {
   symrec *ptr;
   double ret;
@@ -252,6 +258,10 @@ double parse_double(char *name, double def)
     if(!disable_write) {
       fprintf(fout, "%s = %g\n", name, ret);
     }
+    if(fabs(GSL_IMAG(ptr->value.c)) > 1e-10) {
+       fprintf(stderr, "Parser error: complex value passed for real variable '%s'.\n", name);
+       exit(1);
+    }
   }else{
     ret = def;
     if(!disable_write) {
@@ -261,7 +271,7 @@ double parse_double(char *name, double def)
   return ret;
 }
 
-gsl_complex parse_complex(char *name, gsl_complex def)
+gsl_complex parse_complex(const char *name, gsl_complex def)
 {
   symrec *ptr;
   gsl_complex ret;
@@ -282,18 +292,19 @@ gsl_complex parse_complex(char *name, gsl_complex def)
   return ret;
 }
 
-char *parse_string(char *name, char *def)
+/* FIXME: this function should use strcpy rather than assigning char* */
+char *parse_string(const char *name, char *def)
 {
   symrec *ptr;
   char *ret;
   
-  ptr = getsym(name);	
+  ptr = getsym(name);
   if(ptr){
     if( ptr->type != S_STR){
-      fprintf(stderr, "Input error: expecting a string for variable '%s'.\n", name);
+      fprintf(stderr, "Parser error: expecting a string for variable '%s'.\n", name);
       exit(1);
     }
-    ret = ptr->value.str;
+    ret = ptr->value.str; /* this should use strcpy instead */
     if(!disable_write) {
       fprintf(fout, "%s = \"%s\"\n", name, ret);
     }
@@ -306,13 +317,15 @@ char *parse_string(char *name, char *def)
   return ret;
 }
 
-int parse_block (char *name, sym_block **blk)
+int parse_block (const char *name, sym_block **blk)
 {
   symrec *ptr;
 
   ptr = getsym(name);
   if(ptr && ptr->type == S_BLOCK){
     *blk = ptr->value.block;
+    (*blk)->name = (char *)malloc(strlen(name) + 1);
+    strcpy((*blk)->name, name);
     if(!disable_write) {
       fprintf(fout, "Opened block '%s'\n", name);
     }
@@ -325,36 +338,39 @@ int parse_block (char *name, sym_block **blk)
 
 int parse_block_end (sym_block **blk)
 {
-  *blk = NULL;
   if(!disable_write) {
-    fprintf(fout, "Closed block\n");
+     fprintf(fout, "Closed block '%s'\n", (*blk)->name);
   }
+  free((*blk)->name);
+  *blk = NULL;
   return 0;
 }
 
-int parse_block_n(sym_block *blk)
+int parse_block_n(const sym_block *blk)
 {
   assert(blk != NULL);
 
   return blk->n;
 }
 
-int parse_block_cols(sym_block *blk, int l)
+int parse_block_cols(const sym_block *blk, int l)
 {
   assert(blk!=NULL);
-  assert(l>=0 && l<blk->n);
+  if(l < 0 || l >= blk->n){
+    fprintf(stderr, "Parser error: row %i out of range [0,%i] when parsing block '%s'.\n", l, blk->n-1, blk->name);
+    exit(1);
+  }
   
   return blk->lines[l].n;
 }
 
-static int parse_block_work(sym_block *blk, int l, int col, parse_result *r)
+static int parse_block_work(const sym_block *blk, int l, int col, parse_result *r)
 {
   assert(blk!=NULL);
   assert(l>=0 && l<blk->n);
-  assert(col>=0);
 
-  if(col >= blk->lines[l].n){
-    fprintf(stderr, "%s\n", "Input error: not enough columns found when parsing block.");
+  if(col < 0 || col >= blk->lines[l].n){
+    fprintf(stderr, "Parser error: column %i out of range [0,%i] when parsing block '%s'.\n", col, blk->lines[l].n-1, blk->name);
     exit(1);
   }
   
@@ -362,17 +378,29 @@ static int parse_block_work(sym_block *blk, int l, int col, parse_result *r)
 }
 
 
-int parse_block_int(sym_block *blk, int l, int col, int *r)
+int parse_block_int(const sym_block *blk, int l, int col, int *r)
 {
   int o;
   parse_result pr;
 
   o = parse_block_work(blk, l, col, &pr);
 
-  if(o == 0 && pr.type == PR_CMPLX){
-    *r = ROUND(GSL_REAL(pr.value.c));
-    if(!disable_write) {
-      fprintf(fout, "  (%d, %d) = %d\n", l, col, *r);
+  if(o == 0) {
+    if(pr.type == PR_CMPLX){
+      *r = ROUND(GSL_REAL(pr.value.c));
+      if(!disable_write) {
+	fprintf(fout, "  %s (%d, %d) = %d\n", blk->name, l, col, *r);
+      }
+      if(fabs(GSL_IMAG(pr.value.c)) > 1e-10) {
+        fprintf(stderr, "Parser error: complex value passed for integer field in block '%s'.\n", blk->name);
+	exit(1);
+      }
+      if(fabs(*r - GSL_REAL(pr.value.c)) > 1e-10) {
+	fprintf(stderr, "Parser error: non-integer value passed for integer field in block '%s'.\n", blk->name);
+        exit(1);
+      }
+    } else {
+      o = -1;
     }
   }
 
@@ -380,17 +408,25 @@ int parse_block_int(sym_block *blk, int l, int col, int *r)
   return o;
 }
 
-int parse_block_double(sym_block *blk, int l, int col, double *r)
+int parse_block_double(const sym_block *blk, int l, int col, double *r)
 {
   int o;
   parse_result pr;
   
   o = parse_block_work(blk, l, col, &pr);
   
-  if(o == 0 && pr.type == PR_CMPLX){
-    *r = GSL_REAL(pr.value.c);
-    if(!disable_write) {
-      fprintf(fout, "  (%d, %d) = %g\n", l, col, *r);
+  if(o == 0) {
+    if(pr.type == PR_CMPLX){
+      *r = GSL_REAL(pr.value.c);
+      if(!disable_write) {
+        fprintf(fout, "  %s (%d, %d) = %g\n", blk->name, l, col, *r);
+      }
+      if(fabs(GSL_IMAG(pr.value.c)) > 1e-10) {
+        fprintf(stderr, "Parser error: complex value passed for real field in block '%s'.\n", blk->name);
+	exit(1);
+      }
+    } else {
+      o = -1;
     }
   }
   
@@ -398,17 +434,21 @@ int parse_block_double(sym_block *blk, int l, int col, double *r)
   return o;
 }
 
-int parse_block_complex(sym_block *blk, int l, int col, gsl_complex *r)
+int parse_block_complex(const sym_block *blk, int l, int col, gsl_complex *r)
 {
   int o;
   parse_result pr;
 
   o = parse_block_work(blk, l, col, &pr);
-  
-  if(o == 0 && pr.type == PR_CMPLX){
-    *r = pr.value.c;
-    if(!disable_write) {
-      fprintf(fout, "  (%d, %d) = (%g,%g)\n", l, col, GSL_REAL(*r), GSL_IMAG(*r));
+
+  if(o == 0) {
+    if(pr.type == PR_CMPLX){
+      *r = pr.value.c;
+      if(!disable_write) {
+        fprintf(fout, "  %s (%d, %d) = (%g,%g)\n", blk->name, l, col, GSL_REAL(*r), GSL_IMAG(*r));
+      }
+    } else {
+      o = -1;
     }
   }
 
@@ -416,17 +456,21 @@ int parse_block_complex(sym_block *blk, int l, int col, gsl_complex *r)
   return o;
 }
 
-int parse_block_string(sym_block *blk, int l, int col, char **r)
+int parse_block_string(const sym_block *blk, int l, int col, char **r)
 {
   int o;
   parse_result pr;
 
   o = parse_block_work(blk, l, col, &pr);
 
-  if(o == 0 && pr.type == PR_STR){
-    *r = strdup(pr.value.s);
-    if(!disable_write) {
-      fprintf(fout, "  (%d, %d) = \"%s\"\n", l, col, *r);
+  if(o == 0) {
+    if(pr.type == PR_STR){
+      *r = strdup(pr.value.s);
+      if(!disable_write) {
+        fprintf(fout, "  %s (%d, %d) = \"%s\"\n", blk->name, l, col, *r);
+      }
+    } else {
+      o = -1;
     }
   }
 
@@ -443,20 +487,26 @@ void parse_result_free(parse_result *t)
 }
 
 
-void parse_putsym_int(char *s, int i)
+void parse_putsym_int(const char *s, int i)
 {
   symrec *rec = putsym(s, S_CMPLX);
   GSL_SET_COMPLEX(&rec->value.c, (double)i, 0);
+  rec->def = 1;
+  rec->used = 1;
 }
 
-void parse_putsym_double(char *s, double d)
+void parse_putsym_double(const char *s, double d)
 {
   symrec *rec =  putsym(s, S_CMPLX);
   GSL_SET_COMPLEX(&rec->value.c, d, 0);
+  rec->def = 1;
+  rec->used = 1;
 }
 
-void parse_putsym_complex(char *s, gsl_complex c)
+void parse_putsym_complex(const char *s, gsl_complex c)
 {
   symrec *rec =  putsym(s, S_CMPLX);
-  rec->value.c = c;	
+  rec->value.c = c;
+  rec->def = 1;
+  rec->used = 1;
 }
