@@ -16,7 +16,7 @@
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.
 
- $Id: symbols.c 14152 2015-05-29 17:17:41Z dstrubbe $
+ $Id: symbols.c 14262 2015-06-12 17:49:58Z dstrubbe $
 */
 
 #include <stdio.h>
@@ -35,15 +35,13 @@
 /* The symbol table: a chain of `struct symrec'.  */
 symrec *sym_table = (symrec *)0;
 
-char *str_tolower(char *in)
+void str_tolower(char *in)
 {
-  char *s;
-  for(s=in; *s; s++)
-    *s = (char)tolower(*s);
-  return in;
+  for(; *in; in++)
+    *in = (char)tolower(*in);
 }
 
-symrec *putsym (char *sym_name, symrec_type sym_type)
+symrec *putsym (const char *sym_name, symrec_type sym_type)
 {
   symrec *ptr;
   ptr = (symrec *)malloc(sizeof(symrec));
@@ -53,6 +51,7 @@ symrec *putsym (char *sym_name, symrec_type sym_type)
   str_tolower(ptr->name);
   
   ptr->def  = 0;
+  ptr->used = 0;
   ptr->type = sym_type;
   GSL_SET_COMPLEX(&ptr->value.c, 0, 0); /* set value to 0 even if fctn.  */
   ptr->next = (struct symrec *)sym_table;
@@ -60,17 +59,19 @@ symrec *putsym (char *sym_name, symrec_type sym_type)
   return ptr;
 }
 
-symrec *getsym (char *sym_name)
+symrec *getsym (const char *sym_name)
 {
   symrec *ptr;
   for (ptr = sym_table; ptr != (symrec *) 0;
        ptr = (symrec *)ptr->next)
-    if (strcasecmp(ptr->name,sym_name) == 0)
+    if (strcasecmp(ptr->name,sym_name) == 0){
+      ptr->used = 1;
       return ptr;
+    }
   return (symrec *) 0;
 }
 
-int rmsym (char *sym_name)
+int rmsym (const char *sym_name)
 {
   symrec *ptr, *prev;
   for (prev = (symrec *) 0, ptr = sym_table; ptr != (symrec *) 0;
@@ -97,13 +98,13 @@ struct init_fntc{
 
 void sym_notdef (symrec *sym)
 {
-  fprintf(stderr, "Input error:\n\tsymbol '%s' used before being defined\n", sym->name);
+  fprintf(stderr, "Parser error: symbol '%s' used before being defined.\n", sym->name);
   exit(1);
 }
 
 void sym_wrong_arg (symrec *sym)
 {
-  fprintf(stderr, "Input error:\n\tfunction '%s' accepts %d argument\n", sym->name, sym->nargs);
+  fprintf(stderr, "Parser error: function '%s' requires %d argument(s).\n", sym->name, sym->nargs);
   exit(1);
 }
 
@@ -160,7 +161,13 @@ static struct init_fntc arith_fncts[] = {
   {"min",    2, (gsl_complex (*)()) &gsl_complex_min_real},
   {"max",    2, (gsl_complex (*)()) &gsl_complex_max_real},
 
-  {"erf",    1, (gsl_complex (*)()) &gsl_complex_erf}, 
+  {"erf",    1, (gsl_complex (*)()) &gsl_complex_erf},
+
+  {"realpart", 1, (gsl_complex (*)()) &gsl_complex_realpart},
+  {"imagpart", 1, (gsl_complex (*)()) &gsl_complex_imagpart},
+  {"round",   1, (gsl_complex (*)()) &gsl_complex_round},
+  {"floor",   1, (gsl_complex (*)()) &gsl_complex_floor},
+  {"ceiling", 1, (gsl_complex (*)()) &gsl_complex_ceiling},
 
   {0, 0, 0}
 };
@@ -195,6 +202,7 @@ void sym_init_table ()  /* puts arithmetic functions in table. */
   for (i = 0; arith_fncts[i].fname != 0; i++){
     ptr = putsym (arith_fncts[i].fname, S_FNCT);
     ptr->def = 1;
+    ptr->used = 1;
     ptr->nargs = arith_fncts[i].nargs;
     ptr->value.fnctptr = arith_fncts[i].fnctptr;
   }
@@ -203,6 +211,7 @@ void sym_init_table ()  /* puts arithmetic functions in table. */
   for (i = 0; arith_cnts[i].fname != 0; i++){
     ptr = putsym(arith_cnts[i].fname, S_CMPLX);
     ptr->def = 1;
+    ptr->used = 1;
     GSL_SET_COMPLEX(&ptr->value.c, arith_cnts[i].re, arith_cnts[i].im);
   }
 }
@@ -251,10 +260,11 @@ void sym_end_table()
   sym_table = NULL;
 }
 
-void sym_output_table()
+void sym_output_table(int only_unused)
 {
   symrec *ptr;
   for(ptr = sym_table; ptr != NULL; ptr = ptr->next){
+    if(only_unused && ptr->used == 1) continue;
     printf("%s", ptr->name);
     switch(ptr->type){
     case S_CMPLX:
