@@ -16,7 +16,7 @@
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.
 
- $Id: symbols.h 12527 2014-10-03 18:44:13Z dstrubbe $
+ $Id: symbols.h 14365 2015-06-24 19:35:06Z dstrubbe $
 */
 
 #ifndef _SYMBOLS_H
@@ -32,16 +32,17 @@ typedef enum{
 /* Data type for links in the chain of symbols. */
 typedef struct symrec{
   char *name;                  /* name of symbol */
-  symrec_type type;            /* type of symbol: either VAR or FNCT */
+  symrec_type type;            /* type of symbol: complex, string, block, or function */
   int def;                     /* has this symbol been defined */
+  int used;                    /* this symbol has been used before */
 
-  int nargs;                   /* if type==FNCT contains the number of arguments of the function */
+  int nargs;                   /* if type==S_FNCT contains the number of arguments of the function */
 
   union {
-    gsl_complex c;             /* value of a VAR */
-    char *str;                 /* value of a STRING */
+    gsl_complex c;             /* value of a S_CMPLX */
+    char *str;                 /* value of a S_STR */
     sym_block *block;          /* to store blocks */
-    gsl_complex (*fnctptr)();  /* value of a FNCT */
+    gsl_complex (*fnctptr)();  /* value of a S_FNCT */
   } value;
 
   struct symrec *next;         /* link field */
@@ -51,16 +52,16 @@ typedef struct symrec{
 extern symrec *sym_table;
 extern char *reserved_symbols[];
 
-symrec *putsym (char *sym_name, symrec_type sym_type);
-symrec *getsym (char *sym_name);
-int      rmsym (char *sym_name);
+symrec *putsym (const char *sym_name, symrec_type sym_type);
+symrec *getsym (const char *sym_name);
+int      rmsym (const char *sym_name);
 
 void sym_notdef(symrec *sym);
 void sym_wrong_arg(symrec *sym);
 void sym_init_table(void);
 void sym_clear_reserved(void);
 void sym_end_table(void);
-void sym_output_table(void);
-char *str_tolower(char *in);
+void sym_output_table(int only_unused);
+void str_tolower(char *in);
 
 #endif
