@@ -17,7 +17,11 @@
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
   02110-1301, USA.
 
-  $Id: io_binary.h 11333 2013-10-14 10:43:46Z joseba $
+  $Id: io_binary.h 13828 2015-04-11 21:54:46Z dstrubbe $
+
+Note: This comment header is excluded by the preprocessor since this
+file is included in both C and Fortran source files, and thus neither
+comment style should be used.
 */
 #endif
 
