@@ -16,7 +16,7 @@
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
   02110-1301, USA.
 
-  $Id: io_csv.c 12405 2014-08-19 18:54:26Z dstrubbe $
+  $Id: io_csv.c 14034 2015-05-19 15:31:40Z dstrubbe $
 */
 
 /* 
@@ -92,7 +92,7 @@ typedef unsigned long uint64_t;
 #endif
 #endif
 
-#include "io_csv.h"
+#include "io_binary.h"
 
 typedef char byte;
 
