@@ -16,7 +16,7 @@
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.
 
- $Id: oct_f.c 13799 2015-04-08 22:44:31Z dstrubbe $
+ $Id: oct_f.c 14801 2015-11-20 18:24:26Z jrfsousa $
 */
 
 #include <config.h>
@@ -41,22 +41,6 @@
 
 #include "string_f.h" /* Fortran <-> c string compatibility issues */
 
-#ifndef F2003_C_PTR
-/* Pointer-handling functions */
-
-void FC_FUNC_(set_null, SET_NULL)
-  (void ** ptr)
-{
-  *ptr = NULL;
-}
-
-int FC_FUNC_(is_null_int, is_null_int)
-  (void ** ptr)
-{
-  return (*ptr == NULL);
-}
-#endif
-
 /* *********************** interface functions ********************** */
 
 void FC_FUNC_(oct_mkdir, OCT_MKDIR)
@@ -156,27 +140,28 @@ void FC_FUNC_(oct_getcwd, OCT_GETCWD)
   TO_F_STR1(s, name);
 }
 
-void FC_FUNC_(oct_realpath, OCT_GETCWD)
+void FC_FUNC_(oct_realpath, OCT_REALPATH)
      (STR_F_TYPE fnam, STR_F_TYPE rnam STR_ARG2)
 {
   char *fn=NULL, *rn=NULL;
   TO_C_STR1(fnam, fn);
-  rn=realpath(fn, NULL);
+  rn = realpath(fn, NULL);
+  free(fn);
   if(rn!=NULL){
     TO_F_STR2(rn, rnam);
   }else{
     TO_F_STR2("", rnam);
   }
-  free(fn);
+  free(rn);
   return;
 }
 
-void FC_FUNC_(oct_dirname, OCT_GETCWD)
+void FC_FUNC_(oct_dirname, OCT_DIRNAME)
      (STR_F_TYPE fnam, STR_F_TYPE dnam STR_ARG2)
 {
   char *fn=NULL, *dn=NULL;
   TO_C_STR1(fnam, fn);
-  dn=dirname(fn);
+  dn = dirname(fn);
   if(dn!=NULL){
     TO_F_STR2(dn, dnam);
   }else{
@@ -186,18 +171,18 @@ void FC_FUNC_(oct_dirname, OCT_GETCWD)
   return;
 }
 
-void FC_FUNC_(oct_basename, OCT_GETCWD)
+void FC_FUNC_(oct_basename, OCT_BASENAME)
      (STR_F_TYPE fnam, STR_F_TYPE bnam STR_ARG2)
 {
   char *fn=NULL, *bn=NULL;
   TO_C_STR1(fnam, fn);
-  bn=basename(fn);
+  bn = basename(fn);
+  free(fn);
   if(bn!=NULL){
     TO_F_STR2(bn, bnam);
   }else{
     TO_F_STR2("", bnam);
   }
-  free(fn);
   return;
 }
 
@@ -264,7 +249,7 @@ void FC_FUNC_(oct_wfs_list, OCT_WFS_LIST)
 void FC_FUNC_(oct_progress_bar, OCT_PROGRESS_BAR)
   (fint *a, fint *max)
 {
-  if (*max == 0) return; /* Skip the bar if the lenght is 0 */
+  if (*max == 0) return; /* Skip the bar if the length is 0 */
   progress_bar(*a, *max);
 }
 
@@ -333,7 +318,7 @@ void FC_FUNC_(oct_sysname, OCT_SYSNAME)
 }
 
 
-int FC_FUNC_(number_of_lines, NUMBER_OF_LINES)
+int FC_FUNC_(oct_number_of_lines, OCT_NUMBER_OF_LINES)
   (STR_F_TYPE name STR_ARG1)
 {
 
@@ -361,7 +346,7 @@ int FC_FUNC_(number_of_lines, NUMBER_OF_LINES)
 /* Given a string in C, it breaks it line by line and returns each 
    as a Fortran string. Returns 0 if string does not have more lines. 
 */
-void FC_FUNC_(break_c_string, BREAK_C_STRING)
+void FC_FUNC_(oct_break_c_string, OCT_BREAK_C_STRING)
   (char **str, char **s, STR_F_TYPE line_f STR_ARG1)
 {
   char *c, line[256]; /* hopefully no line is longer than 256 characters ;) */
@@ -395,7 +380,7 @@ The value found is returned in the freq argument.
 ierr results:
 0 : value found
 1 : no matching file found
-2 : cannot open the directory
+2 : cannot open the directory or function not available
  
 */
 
@@ -448,10 +433,13 @@ void FC_FUNC_(oct_search_file_lr, OCT_SEARCH_FILE_LR)
       } else continue;
 
 
-      /* if this is the first number we found or the value is closer than previous */
-      if ( !found_something || (fabs(fabs(min)-fabs(*freq)) > fabs(fabs(read_value)-fabs(*freq))) ) {
+      /* if this is the first number we found */
+      if ( !found_something ) {
 	min = read_value;
 	found_something = 1;
+      } else if (fabs(fabs(min)-fabs(*freq)) > fabs(fabs(read_value)-fabs(*freq)) ) {
+      /* if the value is closer than previous */
+	min = read_value;
       }
     }
 
@@ -468,7 +456,8 @@ void FC_FUNC_(oct_search_file_lr, OCT_SEARCH_FILE_LR)
 
 #else
 #warning directory search not compiled
-  fprintf(stderr, "Warning: Directory search not implemented.\n");
+  fprintf(stderr, "Warning: Directory search not available since certain C functions are not available.\n");
+  *ierr = 2;
 #endif
 
 }
@@ -485,7 +474,7 @@ float FC_FUNC_(oct_hypotf, OCT_HYPOTF)
   return hypotf(*x, *y);
 }
 
-void * FC_FUNC_(get_memory_usage, GET_MEMORY_USAGE)()
+void * FC_FUNC_(oct_get_memory_usage, OCT_GET_MEMORY_USAGE)()
 {
 #if defined(HAVE_SYSCONF) && defined(HAVE_GETPID)
   static size_t pagesize = 0;
@@ -511,6 +500,6 @@ void * FC_FUNC_(get_memory_usage, GET_MEMORY_USAGE)()
 #endif
 }
 
-void FC_FUNC_(loct_exit_failure, LOCT_EXIT_FAILURE)(){
+void FC_FUNC_(oct_exit_failure, OCT_EXIT_FAILURE)(){
   exit(EXIT_FAILURE);
 }
