@@ -1,5 +1,5 @@
 /*
- Copyright (C) 2006 X. Andrade
+ Copyright (C) 2016 X. Andrade
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.
 
- $Id: signals.c 13799 2015-04-08 22:44:31Z dstrubbe $
+ $Id: signals.c 15000 2016-01-07 00:38:20Z xavier $
 */
 
 #include <config.h>
@@ -24,7 +24,7 @@
 #include <signal.h>
 #endif
 #include <stdlib.h>
-
+#include <unistd.h>
 
 void FC_FUNC_(block_signals, BLOCK_SIGNALS)(){
 #if defined(HAVE_SIGACTION) && defined(HAVE_SIGNAL_H)
@@ -53,3 +53,32 @@ void FC_FUNC_(unblock_signals, UNBLOCK_SIGNALS)(){
 #endif
 }
 
+void FC_FUNC_(dump_call_stack, DUMP_CALL_STACK)(void);
+
+#if defined(HAVE_SIGACTION) && defined(HAVE_SIGNAL_H)
+					       
+void segv_handler(int signum, siginfo_t * si, void * vd){
+  FC_FUNC_(dump_call_stack, DUMP_CALL_STACK)();
+  signal(signum, SIG_DFL);
+  kill(getpid(), signum);
+}
+
+#endif
+						
+void FC_FUNC_(trap_segfault, TRAP_SEGFAULT)(){
+#if defined(HAVE_SIGACTION) && defined(HAVE_SIGNAL_H)
+  struct sigaction act;
+
+  sigemptyset(&act.sa_mask);
+  act.sa_sigaction = segv_handler;
+  act.sa_flags = SA_SIGINFO;
+
+  sigaction(SIGSEGV, &act, 0);
+  sigaction(SIGABRT, &act, 0);
+  sigaction(SIGINT,  &act, 0);
+  sigaction(SIGTSTP, &act, 0);
+  sigaction(SIGQUIT, &act, 0);
+  sigaction(SIGFPE,  &act, 0);
+  
+#endif
+}
