@@ -15,11 +15,12 @@
 !! Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 !! 02110-1301, USA.
 !!
-!! $Id: global.h 15024 2016-01-09 16:46:25Z xavier $
+!! $Id: global.h 15058 2016-01-14 16:50:31Z xavier $
 
 #include "config_F90.h"
-
-
+#include "options.h"  
+#include "defaults.h"
+  
 ! If the compiler accepts long Fortran lines, it is better to use that
 ! capacity, and build all the preprocessor definitions in one line. In
 ! this way, the debuggers will provide the right line numbers.
@@ -51,11 +52,10 @@
 ! is defined). Otherwise it is merely a logical assertion that, when fails,
 ! prints out the assertion string, the file, and the line. The subroutine
 ! assert_die is in the global_m module.
-#define __STRING(x)     #x
 #if !defined(NDEBUG)
 #  define ASSERT(expr)  \
   if(.not.(expr)) _anl_ \
-     call assert_die(__STRING(expr), _anl_ __FILE__, _anl_  __LINE__) \
+     call assert_die(TOSTRING(expr), _anl_ __FILE__, _anl_  __LINE__) \
   CARDINAL
 #else
 #  define ASSERT(expr)
@@ -81,10 +81,10 @@
 #else
 #  define SAFE_ALLOCATE(x)			\
   allocate(x, stat=global_alloc_err); _newline_ \
-  if(iand(prof_vars%mode, PROFILING_MEMORY).ne.0 .or. global_alloc_err.ne.0) _anl_ \
+  if(not_in_openmp() .and. iand(prof_vars%mode, PROFILING_MEMORY).ne.0 .or. global_alloc_err.ne.0) _anl_ \
   global_sizeof = SIZEOF(x); _newline_	\
   if(iand(prof_vars%mode, PROFILING_MEMORY).ne.0) _anl_ \
-    call profiling_memory_allocate(_anl_ #x, _anl_ __FILE__, _anl_ __LINE__, _anl_ global_sizeof); _newline_ \
+    call profiling_memory_allocate(_anl_ TOSTRING(x), _anl_ __FILE__, _anl_ __LINE__, _anl_ global_sizeof); _newline_ \
   if(global_alloc_err.ne.0) _anl_ \
     call alloc_error(global_sizeof, _anl_ __FILE__, _anl_ __LINE__); \
   CARDINAL
@@ -92,8 +92,8 @@
 #  define MY_DEALLOCATE(x) \
   global_sizeof = SIZEOF(x); _newline_ \
   deallocate(x, stat=global_alloc_err); _newline_ \
-  if(iand(prof_vars%mode, PROFILING_MEMORY).ne.0) _anl_ \
-    call profiling_memory_deallocate(#x, _anl_ __FILE__, _anl_ __LINE__, _anl_ global_sizeof); _newline_ \
+  if(not_in_openmp() .and. iand(prof_vars%mode, PROFILING_MEMORY).ne.0) _anl_ \
+    call profiling_memory_deallocate(TOSTRING(x), _anl_ __FILE__, _anl_ __LINE__, _anl_ global_sizeof); _newline_ \
   if(global_alloc_err.ne.0) _anl_ \
     call dealloc_error(global_sizeof, _anl_ __FILE__, _anl_ __LINE__); \
   CARDINAL
@@ -120,50 +120,20 @@
 #define REAL_DOUBLE real(8)
 #define REAL_SINGLE real(4)
 
-#if defined(SINGLE_PRECISION)
-#  define REAL_PRECISION 4
-#  define FLOAT     	 real(4)
-#  define MPI_FLOAT 	 MPI_REAL
-#  define MPI_2FLOAT     MPI_2REAL
-#  define CMPLX     	 complex(4)
-#  define MPI_CMPLX 	 MPI_COMPLEX
-#  define PREC(x)   	 s ## x
-#  define ZPREC(x)   	 c ## x
-#  define CNST(x)   	 x ## _4
-#  define XC_F90(x)      xc_s_f90_ ## x
-#else
-#  define REAL_PRECISION 8
-#  define FLOAT          real(8)
-#  define MPI_FLOAT 	 MPI_DOUBLE_PRECISION
-#  define MPI_2FLOAT     MPI_2DOUBLE_PRECISION
-#  define CMPLX     	 complex(8)
-#  define MPI_CMPLX 	 MPI_DOUBLE_COMPLEX
-#  define PREC(x)   	 d ## x
-#  define ZPREC(x)   	 z ## x
-#  define CNST(x)   	 x ## _8
-#  define XC_F90(x)      xc_f90_ ## x
-#endif
+#define REAL_PRECISION 8
+#define FLOAT          real(8)
+#define MPI_FLOAT 	 MPI_DOUBLE_PRECISION
+#define MPI_2FLOAT     MPI_2DOUBLE_PRECISION
+#define CMPLX     	 complex(8)
+#define MPI_CMPLX 	 MPI_DOUBLE_COMPLEX
+#define PREC(x)   	 d ## x
+#define ZPREC(x)   	 z ## x
+#define CNST(x)   	 x ## _8
+#define XC_F90(x)      xc_f90_ ## x
 
 #define   TOFLOAT(x) real(x, REAL_PRECISION)
 #define   TOCMPLX(x, y) cmplx(x, y, REAL_PRECISION)
 
-#define M_ONE CNST(1.0)
-#define M_ZERO CNST(0.0)
-
-
-! The code directories should be defined here, and not hard coded in the Fortran files.
-#define GS_DIR "gs/"
-#define TD_DIR "td/"
-#define STATIC_DIR "static/"
-#define EM_RESP_DIR "em_resp/"
-#define EM_RESP_FD_DIR "em_resp_fd/"
-#define KDOTP_DIR "kdotp/"
-#define VIB_MODES_DIR "vib_modes/"
-#define VDW_DIR "vdw/"
-#define CASIDA_DIR "casida/"
-#define OCT_DIR "opt-control/"
-
-
 ! The MPI1 and MPI2 standards are different regarding the MPI_IN_PLACE constant. In
 ! the code, just use the MPI_IN_PLACE_OR defined here.
 #ifdef HAVE_MPI
@@ -187,12 +157,16 @@
 ! pieces of code that call the push_sub and pop_sub routines defined
 ! in the messages_m module.
 #define PUSH_SUB(routine) \
-  if(in_debug_mode) then; _newline_ \
-    call push_sub(__FILE__+"." _anl_ +TOSTRING(routine)); _newline_ \
+  if(debug%trace) then; _newline_ \
+    if(not_in_openmp()) then; _newline_ \
+      call push_sub(__FILE__+"." _anl_ +TOSTRING(routine)); _newline_ \
+    endif; _newline_ \
   endif
 #define POP_SUB(routine) \
-  if(in_debug_mode) then; _newline_ \
-    call pop_sub(__FILE__+"." _anl_ +TOSTRING(routine)); _newline_ \
+  if(debug%trace) then; _newline_ \
+    if(not_in_openmp()) then; _newline_ \
+      call pop_sub(__FILE__+"." _anl_ +TOSTRING(routine)); _newline_ \
+    endif; _newline_ \
   endif
 
 ! the leading dimension of the array
