@@ -16,7 +16,7 @@
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.
 
- $Id: nfft_f.c 11819 2014-02-25 20:24:11Z dstrubbe $
+ $Id: nfft_f.c 14386 2015-06-26 11:50:20Z umberto $
 */
 
 #include <config.h>
@@ -100,36 +100,34 @@ void FC_FUNC(oct_nfft_precompute_one_psi_1d, OCT_NFFT_PRECOMPUTE_ONE_PSI_1D)
 }
 
 void FC_FUNC(oct_nfft_precompute_one_psi_2d, OCT_NFFT_PRECOMPUTE_ONE_PSI_2D)
-     (nfft_plan *plan, int *m, double* X1, double* X2)
+     (nfft_plan *plan, int *M, double* X1, double* X2)
 {
    int ii;
    int jj;
-   int M = *m;
-   
-   for (ii=0; ii< M; ii++){
-     for (jj=0; jj< M; jj++){
-       plan->x[2*(M * ii + jj) + 0] =  X1[ii];
-       plan->x[2*(M * ii + jj) + 1] =  X2[jj];
+
+   for (ii=0; ii< M[0]; ii++){
+     for (jj=0; jj< M[1]; jj++){
+       plan->x[2*(M[1] * ii + jj) + 0] =  X1[ii];
+       plan->x[2*(M[1] * ii + jj) + 1] =  X2[jj];
      }
-   }
-
+    }
 
+ 
    if(plan->nfft_flags & PRE_ONE_PSI)
      nfft_precompute_one_psi(plan);
 }
 
 void FC_FUNC(oct_nfft_precompute_one_psi_3d, OCT_NFFT_PRECOMPUTE_ONE_PSI_3D)
-     (nfft_plan *plan, int *m, double* X1, double* X2, double* X3)
+     (nfft_plan *plan, int *M, double* X1, double* X2, double* X3)
 {
    int ii,jj,kk;
-   int M = *m;
 
-   for (ii=0;ii< M;ii++){
-     for (jj=0;jj< M;jj++){
-       for (kk=0;kk< M;kk++){
-         plan->x[3*(M*M*ii+M*jj+kk) + 0] =  X1[ii];
-         plan->x[3*(M*M*ii+M*jj+kk) + 1] =  X2[jj];
-         plan->x[3*(M*M*ii+M*jj+kk) + 2] =  X3[kk];
+   for (ii=0;ii< M[0];ii++){
+     for (jj=0;jj< M[1];jj++){
+       for (kk=0;kk< M[2];kk++){
+         plan->x[3*(M[1]*M[2]*ii + M[2]*jj + kk) + 0] =  X1[ii];
+         plan->x[3*(M[1]*M[2]*ii + M[2]*jj + kk) + 1] =  X2[jj];
+         plan->x[3*(M[1]*M[2]*ii + M[2]*jj + kk) + 2] =  X3[kk];
        }
      }
    }
@@ -139,39 +137,37 @@ void FC_FUNC(oct_nfft_precompute_one_psi_3d, OCT_NFFT_PRECOMPUTE_ONE_PSI_3D)
 }
 
 // Type dependent functions 
-// This is done the "stupid" way copying and modifying the functions for double and complex types  
 
 
 // ********** COMPLEX ************
 void FC_FUNC(zoct_set_f, ZOCT_SET_F)
-    (nfft_plan *plan, int *m, int *DIM, double complex *VAL, int *IX, int *IY, int *IZ)
+    (nfft_plan *plan, int *M, int *DIM, double complex *VAL, int *IX, int *IY, int *IZ)
 {
-  int M = *m;
+
   int dim = *DIM;
   int ix = *IX;
   int iy = *IY;
   int iz = *IZ;
   double complex val = *VAL;
   
-
    switch (dim){
      case 1:
        plan->f[ix-1] = val;
      break;
      case 2:
-       plan->f[(ix-1)*M + (iy-1)] = val;
+     plan->f[(ix-1)*M[1] + (iy-1)] = val;
      break;
      case 3:
-       plan->f[(ix-1)*M*M + (iy-1)*M + (iz-1)] = val;
+       plan->f[(ix-1)*M[1]*M[2] + (iy-1)*M[2] + (iz-1)] = val;
      break;
-   }
+     }
 
 }
 
 void FC_FUNC(zoct_get_f, ZOCT_GET_F)
-    (nfft_plan *plan, int *m, int *DIM, double complex *val, int *IX, int *IY, int *IZ)
+    (nfft_plan *plan, int *M, int *DIM, double complex *val, int *IX, int *IY, int *IZ)
 {
-  int M = *m;
+
   int dim = *DIM;
   int ix = *IX;
   int iy = *IY;
@@ -183,10 +179,10 @@ void FC_FUNC(zoct_get_f, ZOCT_GET_F)
        *val = plan->f[ix-1];
      break;
      case 2:
-       *val = plan->f[(ix-1)*M + (iy-1)];
+       *val = plan->f[(ix-1)*M[1] + (iy-1)];
      break;
      case 3:
-       *val = plan->f[(ix-1)*M*M + (iy-1)*M + (iz-1)];
+       *val = plan->f[(ix-1)*M[1]*M[2] + (iy-1)*M[2] + (iz-1)];
      break;
    }
 
@@ -194,7 +190,7 @@ void FC_FUNC(zoct_get_f, ZOCT_GET_F)
 
 
 void FC_FUNC(zoct_set_f_hat, ZOCT_SET_F_HAT)
-    (nfft_plan *plan, int *m, int *DIM, double complex *VAL, int *IX, int *IY, int *IZ)
+    (nfft_plan *plan, int *DIM, double complex *VAL, int *IX, int *IY, int *IZ)
 {
   int dim = *DIM;
   int ix = *IX;
@@ -217,7 +213,7 @@ void FC_FUNC(zoct_set_f_hat, ZOCT_SET_F_HAT)
 }
 
 void FC_FUNC(zoct_get_f_hat, ZOCT_GET_F_HAT)
-    (nfft_plan *plan, int *m, int *DIM, double complex *val, int *IX, int *IY, int *IZ)
+    (nfft_plan *plan, int *DIM, double complex *val, int *IX, int *IY, int *IZ)
 {
   int dim = *DIM;
   int ix = *IX;
@@ -233,7 +229,7 @@ void FC_FUNC(zoct_get_f_hat, ZOCT_GET_F_HAT)
        *val = plan->f_hat[(ix-1)*plan->N[1] + (iy-1)];
      break;
      case 3:
-       *val = plan->f_hat[(ix-1)*plan->N[1]*plan->N[2] + (iy-1)*plan->N[1] + (iz-1)];
+       *val = plan->f_hat[(ix-1)*plan->N[1]*plan->N[2] + (iy-1)*plan->N[2] + (iz-1)];
      break;
    }
 
@@ -241,9 +237,9 @@ void FC_FUNC(zoct_get_f_hat, ZOCT_GET_F_HAT)
 
 // ********** DOUBLE ************
 void FC_FUNC(doct_set_f, DOCT_SET_F)
-    (nfft_plan *plan, int *m, int *DIM, double *VAL, int *IX, int *IY, int *IZ)
+    (nfft_plan *plan, int *M, int *DIM, double *VAL, int *IX, int *IY, int *IZ)
 {
-  int M = *m;
+
   int dim = *DIM;
   int ix = *IX;
   int iy = *IY;
@@ -256,19 +252,19 @@ void FC_FUNC(doct_set_f, DOCT_SET_F)
        plan->f[ix-1] = val;
      break;
      case 2:
-       plan->f[(ix-1)*M + (iy-1)] = val;
+       plan->f[(ix-1)*M[1] + (iy-1)] = val;
      break;
      case 3:
-       plan->f[(ix-1)*M*M + (iy-1)*M + (iz-1)] = val;
+       plan->f[(ix-1)*M[1]*M[2] + (iy-1)*M[2] + (iz-1)] = val;
      break;
    }
 
 }
 
 void FC_FUNC(doct_get_f, DOCT_GET_F)
-    (nfft_plan *plan, int *m, int *DIM, double *val, int *IX, int *IY, int *IZ)
+    (nfft_plan *plan, int *M, int *DIM, double *val, int *IX, int *IY, int *IZ)
 {
-  int M = *m;
+
   int dim = *DIM;
   int ix = *IX;
   int iy = *IY;
@@ -280,10 +276,10 @@ void FC_FUNC(doct_get_f, DOCT_GET_F)
        *val = plan->f[ix-1];
      break;
      case 2:
-       *val = plan->f[(ix-1)*M + (iy-1)];
+       *val = plan->f[(ix-1)*M[1] + (iy-1)];
      break;
      case 3:
-       *val = plan->f[(ix-1)*M*M + (iy-1)*M + (iz-1)];
+       *val = plan->f[(ix-1)*M[1]*M[2] + (iy-1)*M[2] + (iz-1)];
      break;
    }
 
@@ -291,7 +287,7 @@ void FC_FUNC(doct_get_f, DOCT_GET_F)
 
 
 void FC_FUNC(doct_set_f_hat, DOCT_SET_F_HAT)
-    (nfft_plan *plan, int *m, int *DIM, double *VAL, int *IX, int *IY, int *IZ)
+    (nfft_plan *plan, int *DIM, double *VAL, int *IX, int *IY, int *IZ)
 {
   int dim = *DIM;
   int ix = *IX;
@@ -314,7 +310,7 @@ void FC_FUNC(doct_set_f_hat, DOCT_SET_F_HAT)
 }
 
 void FC_FUNC(doct_get_f_hat, DOCT_GET_F_HAT)
-    (nfft_plan *plan, int *m, int *DIM, double *val, int *IX, int *IY, int *IZ)
+    (nfft_plan *plan, int *DIM, double *val, int *IX, int *IY, int *IZ)
 {
   int dim = *DIM;
   int ix = *IX;
@@ -330,7 +326,7 @@ void FC_FUNC(doct_get_f_hat, DOCT_GET_F_HAT)
        *val = plan->f_hat[(ix-1)*plan->N[1] + (iy-1)];
      break;
      case 3:
-       *val = plan->f_hat[(ix-1)*plan->N[1]*plan->N[2] + (iy-1)*plan->N[1] + (iz-1)];
+       *val = plan->f_hat[(ix-1)*plan->N[1]*plan->N[2] + (iy-1)*plan->N[2] + (iz-1)];
      break;
    }
 
