@@ -17,7 +17,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301, USA.
 #
-# $Id: oct-run_regression_test.pl 14747 2015-11-07 20:39:10Z dstrubbe $
+# $Id: oct-run_regression_test.pl 15022 2016-01-09 04:19:06Z xavier $
 
 use warnings;
 use Getopt::Std;
@@ -30,7 +30,7 @@ sub usage {
 
   print <<EndOfUsage;
 
- Copyright (C) 2005-2014 H. Appel, M. Marques, X. Andrade, D. Strubbe
+ Copyright (C) 2005-2016 H. Appel, M. Marques, X. Andrade, D. Strubbe
 
 Usage: oct-run_regression_test.pl [options]
 
@@ -38,7 +38,7 @@ Usage: oct-run_regression_test.pl [options]
     -v        verbose
     -h        this usage
     -D        name of the directory where to look for the executables   
-    -s        exec suffix for the executables
+    -s        run everything serial
     -f        filename of testsuite [required]
     -p        preserve working directories
     -l        copy output log to current directory
@@ -61,8 +61,6 @@ sub set_precision{
   my $p = $_[0];
   if($p ne "default"){
     $precnum = 1.0*$p;
-  }elsif($_[1] =~ m/_single/){
-    $precnum = 0.001
   } else {
     $precnum = 0.0001
   }
@@ -88,11 +86,13 @@ if(-t STDOUT) {
 
 if (not @ARGV) { usage; }
 
-getopts("nlvhD:c:f:s:pm");
+$opt_f = "";
+getopts("nlvhD:c:f:spm");
 
 # avoid warnings 'used only once: possible typo'
 $useless = $opt_h;
 $useless = $opt_l;
+$useless = $opt_s;
 
 # Default values
 use File::Temp qw/tempdir/;
@@ -111,55 +111,53 @@ if($opt_D) {
 }
 
 if(length($opt_f) == 0) {
-    die255("ERROR: You must supply the name of a test file with the -f option.\n");
+    die255("You must supply the name of a test file with the -f option.");
 }
 
-# Find out which executables are available.
-opendir(EXEC_DIRECTORY, $exec_directory) || 
- die255("ERROR: Could not open the directory $exec_directory to look for executables");
-@octopus_execs = grep { /^oct/ } readdir(EXEC_DIRECTORY);
-closedir(EXEC_DIRECTORY);
-
-# determine exec suffix
-$exec_suffix = "";
-if($opt_s)  { $exec_suffix = $opt_s; }
-
 $aexec = get_env("EXEC");
 $global_np = get_env("OCT_TEST_MPI_NPROCS");
 
-$mpiexec = get_env("MPIEXEC");
-$machinelist = get_env("MACHINELIST");
-if ("$mpiexec" eq "") { $mpiexec = `which mpiexec 2> /dev/null`; }
-chomp($mpiexec);
+# FIXME: all test files should declare Processors
+#$np = "serial";
+$is_parallel = 0;
 
+# FIXME: could bake in mpiexec at configure time
+
+if(!$opt_s) {
+# MPI stuff
+    $mpiexec = get_env("MPIEXEC");
+    $machinelist = get_env("MACHINELIST");
+    if ("$mpiexec" eq "") { $mpiexec = `which mpiexec 2> /dev/null`; }
+    chomp($mpiexec);
+
+    if( "$mpiexec" eq "" ) { 
+	print "No mpiexec found: running in serial.\n\n";
+    } else {
 # mpiexec without arguments (to check if it is available)
-$mpiexec_raw = $mpiexec;
-$mpiexec_raw =~ s/\ (.*)//;
-
-if ("$mpiexec_raw" ne "") {
-    if(!( -e "$mpiexec_raw")) {
-	print "mpiexec ($mpiexec_raw) does not exist\n";
-    } elsif(!( -x "$mpiexec_raw")) {
-	print "mpiexec ($mpiexec_raw) is not executable\n";
+	$mpiexec_raw = $mpiexec;
+	$mpiexec_raw =~ s/\ (.*)//;
+	if ( ! -e "$mpiexec_raw" ) {
+	    print "mpiexec command ($mpiexec_raw) does not exist: running in serial.\n\n";
+	    $mpiexec = "";
+	} elsif( ! -x "$mpiexec_raw" ) {
+	    print "mpiexec command ($mpiexec_raw) is not executable: running in serial.\n\n";
+	    $mpiexec = "";
+	} else {
+# default number of processors is 1
+	    $np = 1;
+	    $is_parallel = 1;
+	}
     }
-}
-
-# default dummy value, for dry run so MPIEXEC need not be set properly
-if("$mpiexec" eq "") {
-    $mpiexec = "mpiexec";
+} else {
+    $mpiexec = "";
 }
 
 # default number of processors for MPI runs is 2
 $np = 2;
-
-
-# Figure out which are the executables to test
-my @executables;
-if($opt_n) {
-    @executables = "octopus";
-} else {
-    find_executables();
-}
+$enabled = ""; # FIXME: should Enabled be optional?
+$options_required = "";
+$options_required_mpi = "";
+$options_are_mpi = 0;
 
 # This variable counts the number of failed testcases.
 $failures = 0;
@@ -168,44 +166,44 @@ $tempdirpath = get_env("TEMPDIRPATH");
 if ("$tempdirpath" eq "") { $tempdirpath = '/tmp'; }
 if (! -d $tempdirpath) { mkdir $tempdirpath; }
 
-# Loop over all the executables.
-foreach my $octopus_exe (@executables){
+set_precision("default");
+$test_succeeded = 1;
 
-  set_precision("default", $octopus_exe);
-  $test_succeeded = 1;
+$pwd = get_env("PWD");
+if (!$opt_m) {
+    my $name = $opt_f;
+    $name =~ s/\.\.\///g;
+    $name =~ s/\//-/g;
+    $workdir = tempdir("$tempdirpath/octopus" . "-" . $name . ".XXXXXX");
+    chomp($workdir);
 
-  $pwd = get_env("PWD");
-  if (!$opt_m) {
-      $workdir = tempdir("$tempdirpath/octopus.XXXXXX");
-      chomp($workdir);
-
-      system ("rm -rf $workdir");
-      mkdir $workdir;
+    system ("rm -rf $workdir");
+    mkdir $workdir;
       
-      $scriptname = "$workdir/matches.sh";
-      open(SCRIPT, ">$scriptname") or die255("ERROR: could not create '$scriptname'.\n");
-      print SCRIPT "#\!/usr/bin/env bash\n\n";
-      print SCRIPT "perl $pwd/$0 -m -D $exec_directory -f $pwd/$opt_f\n";
-      close(SCRIPT);
-      chmod 0755, $scriptname;
+    $scriptname = "$workdir/matches.sh";
+    open(SCRIPT, ">$scriptname") or die255("Could not create '$scriptname'.");
+    print SCRIPT "#\!/usr/bin/env bash\n\n";
+    print SCRIPT "perl $pwd/$0 -m -D $exec_directory -f $pwd/$opt_f\n";
+    close(SCRIPT);
+    chmod 0755, $scriptname;
       
-      $matchdir = $workdir;
-  } else {
-      $workdir = $pwd;
-  }
+    $matchdir = $workdir;
+} else {
+    $workdir = $pwd;
+}
 
-  # testsuite
-  open(TESTSUITE, "<".$opt_f ) or die255("ERROR: cannot open testsuite file '$opt_f'.\n");
+# testsuite
+open(TESTSUITE, "<".$opt_f ) or die255("Cannot open testsuite file '$opt_f'.");
 
-  $command = $octopus_exe;
-
-  $enabled = "";
-  while ($_ = <TESTSUITE>) {
+while ($_ = <TESTSUITE>) {
 
     # remove trailing newline 
     chomp; 
-    # remove trailing whitespace 
-    $_ =~ s/^\s+//; 
+    # remove leading whitespace 
+    $_ =~ s/^\s+//;
+    # remove trailing whitespace
+    $_ =~ s/\s+$//;
+
     # skip blank lines
     next if (length($_) == 0);
 
@@ -214,13 +212,16 @@ foreach my $octopus_exe (@executables){
 
     if ( $_ =~ /^Test\s*:\s*(.*)\s*$/) {
       $test{"name"} = $1;
+      if($test{"name"} eq "") {
+	  die255("No name was provided with Test tag.");
+      }
       print "$color_start{blue} ***** $test{\"name\"} ***** $color_end{blue} \n\n";
       print "Using workdir    : $workdir\n";
       if($opt_p) {
 	  print "Workdir will be saved.\n";
       }
-      print "Using executable : $octopus_exe\n";
       print "Using test file  : $opt_f \n";
+
     } elsif ( $_ =~ /^Enabled\s*:\s*(.*)\s*$/) {
       %test = ();
       $enabled = $1;
@@ -230,42 +231,83 @@ foreach my $octopus_exe (@executables){
 
       if ( $enabled eq "No") {
           print STDERR "Test disabled: skipping test\n\n";
-	  if (!$opt_p && !$opt_m) { system ("rm -rf $workdir"); }
 	  skip_exit();
       } elsif ( $enabled ne "Yes") {
-	  die255("ERROR: Unknown option 'Enabled = $enabled' in testsuite file.\n\n");
 	  if (!$opt_p && !$opt_m) { system ("rm -rf $workdir"); }
+	  die255("Unknown option 'Enabled = $enabled' in testsuite file.");
       }
-    } elsif ( $_ =~ /^Programs\s*:\s*(.*)\s*$/) {
-        # handled earlier
+
     } elsif ( $_ =~ /^Options\s*:\s*(.*)\s*$/) {
-        # handled earlier
+        $options_required = $1;
+	# note: we could implement Options by baking this into the script via configure...
+	
+    } elsif ( $_ =~ /^Options_MPI\s*:\s*(.*)\s*$/) {
+        if ($is_parallel && $np ne "serial") {
+	    $options_required_mpi = $1;
+	    $options_are_mpi = 1;
+	}
+
+    } elsif ( $_ =~ /^Program\s*:\s*(.*)\s*$/) {
+	$command = "$exec_directory/$1";
+
+	# FIXME: should we do this for a dry-run?
+	if( ! -x "$command") {
+	  $command = "$exec_directory/../utils/$1";
+	}	
+	if( ! -x $command) {
+	    die255("Executable '$1' not available.");
+        }
+
+	$options_available = `$command -c`;
+	chomp($options_available);
+	if($is_parallel && $options_available !~ "mpi") {
+	    print "Running in serial since executable was not compiled with MPI.\n";
+	    $is_parallel = 0;
+	    $options_are_mpi = 0;
+	}
+
+	if($options_are_mpi) {
+	    $options_required = $options_required_mpi;
+	}
+
+	if(length($options_required) > 0) {
+	    # check if the executable was compiled with the required options
+	    foreach my $option (split(/;/, $options_required)){
+		if(" $options_available " !~ " $option ") {
+		    print "\nSkipping test: executable does not have the required option '$option'";
+		    if($options_are_mpi) {
+			print " for MPI";
+		    }
+		    print ".\n";
+		    print "Executable: $command\n";
+		    print "Available options: $options_available\n\n";
+		    skip_exit();
+		}
+	    }
+	}
+	# FIXME: import Options to BGW version
     } elsif ( $_ =~ /^TestGroups\s*:/) {
         # handled by oct-run_testsuite.sh
     } else {
       if ( $enabled eq "") {
-	die255("ERROR: Testsuite file must set Enabled tag before another (except Test, Programs, Options, TestGroups).\n\n");
+	die255("Testsuite file must set Enabled tag before another (except Test, Program, Options, TestGroups).");
       }
 
       if ( $_ =~ /^Util\s*:\s*(.*)\s*$/) {
+	$np = "serial";
 	$command = "$exec_directory/$1";
 	if( ! -x "$command") {
 	  $command = "$exec_directory/../utils/$1";
 	}
 
 	if( ! -x "$command") {
-	  print "\nCannot find utility : $1 . Skipping utilities test \n";
-	  if (!$opt_p && !$opt_m) { system ("rm -rf $workdir"); }
-	  exit $failures;
+	    die255("Cannot find utility '$1'.");
 	}
       }
 
-      elsif ( $_ =~ /^Not_Util/) {
-        $command = $octopus_exe;
-      }
-
       elsif ( $_ =~ /^Processors\s*:\s*(.*)\s*$/) {
-	$np = $1;
+	  # FIXME: enforce this is "serial" or numeric
+	  $np = $1;
       }
 
       elsif ( $_ =~ /^Input\s*:\s*(.*)\s*$/) {
@@ -276,6 +318,7 @@ foreach my $octopus_exe (@executables){
 	if ( $opt_m ) {
 	    print "\n\nFor input file : $input_file\n\n";
 	    $return_value = 0;
+	    # FIXME: this works from outer directory, but not in archived subdirectories.
 	    $matchdir = "$workdir/$input_base";
 	} else {
           if( -f $input_file ) {
@@ -289,48 +332,37 @@ foreach my $octopus_exe (@executables){
             $mode = (stat "$workdir/inp")[2];
             chmod $mode|S_IWUSR, "$workdir/inp";
           } else {
-            die255("ERROR: could not find input file: $input_file\n");
+            die255("Could not find input file '$input_file'.");
           }
       
-	  $command_suffix = $command;
-
 	  # serial or MPI run?
-	  if ( $octopus_exe =~ /mpi$/) {
+	  if ( $is_parallel && $np ne "serial") {
             if("$global_np" ne "") {
 		$np = $global_np;
             }
-	    # utility runs should be on only one processor
-	    if ( $command_suffix !~ /mpi$/) {
-		$np = 1;
-	    }
-	    # we do not need to care if mpiexec works if we are just doing a dry run
-	    if( -x "$mpiexec_raw" || $opt_n) {
-	      if ("$mpiexec" =~ /ibrun/) { # used by SGE parallel environment
-		  $specify_np = "";
-		  $my_nslots = "MY_NSLOTS=$np";
-	      } elsif ("$mpiexec" =~ /runjob/) { # used by BlueGene
-		  $specify_np = "--np $np --exe";
-		  $my_nslots = "";
-	      } elsif ("$mpiexec" =~ /poe/) { # used by IBM PE 
-                  $specify_np = ""; 
-                  $my_nslots = "MP_PROCS=$np"; 
-	      } else { # for mpirun and Cray's aprun
-		  $specify_np = "-n $np";
-		  $my_nslots = "";
-	      }
-	      $command_line = "cd $workdir; $my_nslots $mpiexec $specify_np $machinelist $aexec $command_suffix > out";
-	    } else {
-	      print "No mpiexec found: Skipping parallel test \n";
-	      if (!$opt_p && !$opt_m) { system ("rm -rf $workdir"); }
-	      skip_exit();
+	    if ("$mpiexec" =~ /ibrun/) { # used by SGE parallel environment
+		$specify_np = "";
+		$my_nslots = "MY_NSLOTS=$np";
+	    } elsif ("$mpiexec" =~ /runjob/) { # used by BlueGene
+		$specify_np = "--np $np --exe";
+		$my_nslots = "";
+	    } elsif ("$mpiexec" =~ /poe/) { # used by IBM PE 
+		$specify_np = ""; 
+		$my_nslots = "MP_PROCS=$np"; 
+	    } else { # for mpirun and Cray's aprun
+		$specify_np = "-n $np";
+		$my_nslots = "";
 	    }
+	    $command_line = "cd $workdir; $my_nslots $mpiexec $specify_np $machinelist $aexec $command > out";
 	  } else {
-	      $command_line = "cd $workdir; $aexec $command_suffix > out ";
+	      $command_line = "cd $workdir; $aexec $command > out ";
 	  }
 
-# MPI implementations generally permit using more tasks than actual cores, and running tests this way makes it likely for developers to find race conditions.
-	  if($np > 4) {
-	      print "Note: this run calls for more than the standard maximum of 4 MPI tasks.\n";
+	  # MPI implementations generally permit using more tasks than actual cores, and running tests this way makes it likely for developers to find race conditions.
+	  if($np ne "serial") {
+	      if($np > 4) {
+		  print "Note: this run calls for more than the standard maximum of 4 MPI tasks.\n";
+	      }
 	  }
 
 	  print "Executing: " . $command_line . "\n";
@@ -356,7 +388,7 @@ foreach my $octopus_exe (@executables){
 	      printf "%-40s%s", " Execution", ": \t [ $color_start{red} FAIL $color_end{red} ] \n\n";
 
 	      $failures++;
-	      $test_succeeded = 0;      
+	      $test_succeeded = 0;  
 	    }
 	    $test{"run"} = 1;
 	  }
@@ -375,10 +407,11 @@ foreach my $octopus_exe (@executables){
       }
 
       elsif ( $_ =~ /^Precision\s*:\s*(.*)\s*$/) {
-	set_precision($1, $command) ;
+	set_precision($1);
       }
 
       elsif ( $_ =~ /^match/ ) {
+	  # FIXME: should we do matches even when execution failed?
 	  if (!$opt_n && $return_value == 0) {
 	      if(run_match_new($_)){
 		  printf "%-40s%s", "$name", ":\t [ $color_start{green}  OK  $color_end{green} ] \t (Calculated value = $value) \n";
@@ -391,94 +424,37 @@ foreach my $octopus_exe (@executables){
 	      }
 	  }
       } else {
-	  die255("ERROR: Unknown command '$_'\n");
+	  die255("Unknown command '$_'.");
       }
     }
 
-  }
-
-  if ($opt_l && !$opt_m && !$opt_n)  { system ("cat $workdir/out >> out.log"); }
-  if (!$opt_p && !$opt_m && $test_succeeded) { system ("rm -rf $workdir"); }
-
-  print "\n";
-  close(TESTSUITE)
 }
 
+if ($opt_l && !$opt_m && !$opt_n)  { system ("cat $workdir/out >> out.log"); }
+if (!$opt_p && !$opt_m && $test_succeeded) { system ("rm -rf $workdir"); }
+
+print "\n";
+close(TESTSUITE);
+
 print "Status: ".$failures." failures\n";
 
 exit $failures;
 
 
-sub find_executables {
-  my $name = "";
-  $options = ""; # initialize in case no options specified
-
-  open(TESTSUITE, "<".$opt_f ) or die255("ERROR: cannot open testsuite file '$opt_f'.\n");
-  while ($_ = <TESTSUITE>) {
-
-    if ( $_ =~ /^Test\s*:\s*(.*)\s*$/) {
-      $name = $1;
-    }
-
-    if ( $_ =~ /^Options\s*:\s*(.*)\s*$/) {
-      $options = $1;
-    }
-
-    if ( $_ =~ /^Programs\s*:\s*(.*)\s*$/) {
-      my $i = 0;
-      foreach my $program (split(/;/, $1)) {
-	$program =  "$program$exec_suffix";
-	$program =~ s/^\s+//;
-	foreach my $x (@octopus_execs) {
-	  $valid = $program cmp $x;
-	  if(!$valid) {
-	    # check if the executable was compiled with the required options
-	    $has_options = 1;
-	    $options_available = `$exec_directory/$x -c`;
-	    chomp($options_available);
-	    foreach my $y (split(/;/, $options)){
-	      $has_options = $has_options && (" $options_available " =~ " $y ");
-	    }
-
-	    if($has_options) {
-	      $executables[$i] = "$exec_directory/$x";
-	      $i = $i+1;
-	    }
-	  }
-	}
-      }
-    }
-
-  }
-  close(TESTSUITE);
-
-  if($name eq "") {
-      die255("ERROR: No name was provided with Test tag.\n");
-  }
-
-  # Exit if no suitable executable was found.
-  if( @executables == 0 ){
-    print STDERR "$color_start{blue} ***** $name ***** $color_end{blue} \n\n";
-    print STDERR "$color_start{red}No valid executable$color_end{red} found for $opt_f\n";
-    print STDERR "Skipping ... \n\n";
-    skip_exit();
-  }
-}
-
 sub run_match_new {
-  die255("ERROR: Have to run before matching\n") if !$test{"run"} && !opt_m;
+  die255("Have to run before matching.") if !$test{"run"} && !opt_m;
 
   # parse match line
-  my ($line, $match, $pre_command, $ref_value, $off);
+  my ($line, $match, $match_command, $shell_command, $ref_value, $off);
   $line = $_[0];
   $line =~ s/\\;/_COLUMN_/g;
-  ($match, $name, $pre_command, $ref_value) = split(/;/, $line);
-  $pre_command =~ s/_COLUMN_/;/g;
+  ($match, $name, $match_command, $ref_value) = split(/;/, $line);
+  $match_command =~ s/_COLUMN_/;/g;
   $ref_value =~ s/^\s*//;
   $ref_value =~ s/\s*$//;
 
   # parse command
-  $pre_command =~ /\s*(\w+)\s*\((.*)\)/;
+  $match_command =~ /\s*(\w+)\s*\((.*)\)/;
 
   my $func = $1;
   my $params = $2;
@@ -494,25 +470,25 @@ sub run_match_new {
 
   if($func eq "SHELL"){ # function SHELL(shell code)
     check_num_args(1, 1, $#par, $func);
-    $pre_command = $par[0];
+    $shell_command = $par[0];
 
   }elsif($func eq "LINE") { # function LINE(filename, line, column)
     check_num_args(3, 3, $#par, $func);
     if($par[1] < 0) { # negative number means from end of file
       $line_num = "`wc -l $par[0] | awk '{print \$1}'`";
-      $pre_command = "awk -v n=$line_num '(NR==n+$par[1]+1)' $par[0]";
+      $shell_command = "awk -v n=$line_num '(NR==n+$par[1]+1)' $par[0]";
     } else {
-      $pre_command = "awk '(NR==$par[1])' $par[0]";
+      $shell_command = "awk '(NR==$par[1])' $par[0]";
     }
-    $pre_command .= " | cut -b $par[2]-";
+    $shell_command .= " | cut -b $par[2]-";
 
   }elsif($func eq "LINEFIELD") { # function LINE(filename, line, field)
     check_num_args(3, 3, $#par, $func);
     if($par[1] < 0) { # negative number means from end of file
       $line_num = "`wc -l $par[0] | awk '{print \$1}'`";
-      $pre_command = "awk -v n=$line_num '(NR==n+$par[1]+1) {printf \$$par[2]}' $par[0]";
+      $shell_command = "awk -v n=$line_num '(NR==n+$par[1]+1) {printf \$$par[2]}' $par[0]";
     } else {
-      $pre_command = "awk '(NR==$par[1]) {printf \$$par[2]}' $par[0]";
+      $shell_command = "awk '(NR==$par[1]) {printf \$$par[2]}' $par[0]";
     }
 
   }elsif($func eq "GREP") { # function GREP(filename, 're', column <, [offset>])
@@ -523,8 +499,8 @@ sub run_match_new {
 	$off = 0;
     }
     # -a means even if the file is considered binary due to a stray funny character, it will work
-    $pre_command = "grep -a -A$off $par[1] $par[0] | awk '(NR==$off+1)'";
-    $pre_command .= " | cut -b $par[2]-";
+    $shell_command = "grep -a -A$off $par[1] $par[0] | awk '(NR==$off+1)'";
+    $shell_command .= " | cut -b $par[2]-";
 
   }elsif($func eq "GREPFIELD") { # function GREPFIELD(filename, 're', field <, [offset>])
     check_num_args(3, 4, $#par, $func);
@@ -534,13 +510,13 @@ sub run_match_new {
 	$off = 0;
     }
     # -a means even if the file is considered binary due to a stray funny character, it will work
-    $pre_command = "grep -a -A$off $par[1] $par[0]";
-    $pre_command .= " | awk '(NR==$off+1) {printf \$$par[2]}'";
+    $shell_command = "grep -a -A$off $par[1] $par[0]";
+    $shell_command .= " | awk '(NR==$off+1) {printf \$$par[2]}'";
     # if there are multiple occurrences found by grep, we will only be taking the first one via awk
 
   }elsif($func eq "SIZE") { # function SIZE(filename)
     check_num_args(1, 1, $#par, $func);
-    $pre_command = "ls -lt $par[0] | awk '{printf \$5}'";
+    $shell_command = "ls -lt $par[0] | awk '{printf \$5}'";
 
   }else{ # error
     printf STDERR "ERROR: Unknown command '$func'\n";
@@ -549,11 +525,11 @@ sub run_match_new {
 
   # 'set -e; set -o pipefail' (bash 3 only) would make the whole pipe series give an error if any step does;
   # otherwise the error comes only if the last step failed.
-  $value = qx(cd $matchdir && $pre_command);
+  $value = qx(cd $matchdir && $shell_command);
   # Perl gives error code shifted, for some reason.
   $exit_code = $? >> 8;
   if($exit_code) {
-      print STDERR "ERROR: Match command failed: $pre_command\n";
+      print STDERR "ERROR: Match command failed: $shell_command\n";
       return 0;
   }
 
@@ -566,17 +542,18 @@ sub run_match_new {
   }
 
   if(length($value) == 0) {
-      print STDERR "ERROR: Match command returned nothing: $pre_command\n";
+      print STDERR "ERROR: Match command returned nothing: $shell_command\n";
       return 0;
   }
 
   if(!looks_like_number($value)) {
-      print STDERR "ERROR: Match command returned non-numeric value '$value': $pre_command\n";
+      print STDERR "ERROR: Match command returned non-numeric value '$value': $shell_command\n";
       return 0;
   }
 
   if(!looks_like_number($ref_value)) {
       print STDERR "WARNING: Match command has non-numeric reference value '$value'.\n";
+      return 0;
   }
 
   # at this point, we know that the command was successful, and returned a number.
@@ -615,20 +592,27 @@ sub check_num_args {
     my $func_name      = $_[3];
 
     if($given_num_args < $min_num_args) {
-	die255("$func_name given $given_num_args argument(s) but needs at least $min_num_args.\n");
+	die255("$func_name given $given_num_args argument(s) but needs at least $min_num_args.");
     }
     if($given_num_args > $max_num_args) {
-	die255("$func_name given $given_num_args argument(s) but can take no more than $max_num_args.\n");
+	die255("$func_name given $given_num_args argument(s) but can take no more than $max_num_args.");
     }
 }
 
 sub die255 {
-    print STDERR $_[0];
+    print STDERR "ERROR: " . $_[0] . "\n";
     print "Status: error\n";
     exit 255;
 }
 
 sub skip_exit {
-    print "Status: skipped\n\n";
-    exit 254;  
+    if (!$opt_p && !$opt_m && $test_succeeded) { system ("rm -rf $workdir"); }
+    if($failures == 0) {
+	print "Status: skipped\n";
+	exit 254
+    } else {
+	print "Status: ".$failures." failures\n";
+	exit $failures;
+	# if a previous step has failed, mark as failed not skipped
+    }
 }
